# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_steamtv.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_steamtv.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bsteammessages_steamtv.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"}\n\'CSteamTV_CreateBroadcastChannel_Request\x12R\n\x0bunique_name\x18\x01 \x01(\tB=\x82\xb5\x18\x39Unique short broadcast channel name, part of Steam.TV URL\"g\n(CSteamTV_CreateBroadcastChannel_Response\x12;\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x1d\x82\xb5\x18\x19\x42roadcast channel ID or 0\"V\n&CSteamTV_GetBroadcastChannelID_Request\x12,\n\x0bunique_name\x18\x01 \x01(\tB\x17\x82\xb5\x18\x13\x43hannel short name)\"\xc5\x01\n\'CSteamTV_GetBroadcastChannelID_Response\x12;\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x1d\x82\xb5\x18\x19\x42roadcast channel ID or 0\x12/\n\x0bunique_name\x18\x02 \x01(\tB\x1a\x82\xb5\x18\x16\x42roadcast channel name\x12,\n\x07steamid\x18\x03 \x01(\x06\x42\x1b\x82\xb5\x18\x17\x42roadcast channel owner\"\xfd\x03\n+CSteamTV_SetBroadcastChannelProfile_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\x12#\n\x04name\x18\x02 \x01(\tB\x15\x82\xb5\x18\x11long channel name\x12@\n\x08language\x18\x03 \x01(\tB.\x82\xb5\x18*primary channel language (Steam shortname)\x12.\n\x08headline\x18\x04 \x01(\tB\x1c\x82\xb5\x18\x18short channel desciption\x12,\n\x07summary\x18\x05 \x01(\tB\x1b\x82\xb5\x18\x17long channel desciption\x12.\n\x0b\x61vatar_hash\x18\x06 \x01(\tB\x19\x82\xb5\x18\x15\x63ommunity avatar hash\x12\x30\n\x08schedule\x18\x07 \x01(\tB\x1e\x82\xb5\x18\x1a\x62roadcast channel schedule\x12*\n\x05rules\x18\x08 \x01(\tB\x1b\x82\xb5\x18\x17\x62roadcast channel rules\x12\x43\n\x06panels\x18\t \x01(\tB3\x82\xb5\x18/JSON data representing the channel panel layout\".\n,CSteamTV_SetBroadcastChannelProfile_Response\"e\n+CSteamTV_GetBroadcastChannelProfile_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\"\xb6\x04\n,CSteamTV_GetBroadcastChannelProfile_Response\x12R\n\x0bunique_name\x18\x01 \x01(\tB=\x82\xb5\x18\x39Unique short broadcast channel name, part of Steam.TV URL\x12\x32\n\rowner_steamid\x18\x02 \x01(\x06\x42\x1b\x82\xb5\x18\x17\x42roadcast channel owner\x12#\n\x04name\x18\x03 \x01(\tB\x15\x82\xb5\x18\x11long channel name\x12@\n\x08language\x18\x04 \x01(\tB.\x82\xb5\x18*primary channel language (Steam shortname)\x12/\n\x08headline\x18\x05 \x01(\tB\x1d\x82\xb5\x18\x19short channel description\x12-\n\x07summary\x18\x06 \x01(\tB\x1c\x82\xb5\x18\x18long channel description\x12\x30\n\x08schedule\x18\x07 \x01(\tB\x1e\x82\xb5\x18\x1a\x62roadcast channel schedule\x12*\n\x05rules\x18\x08 \x01(\tB\x1b\x82\xb5\x18\x17\x62roadcast channel rules\x12\x43\n\x06panels\x18\t \x01(\tB3\x82\xb5\x18/JSON data representing the channel panel layout\x12\x14\n\x0cis_partnered\x18\n \x01(\x08\"\x91\x04\n)CSteamTV_SetBroadcastChannelImage_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\x12Y\n\nimage_type\x18\x02 \x01(\x0e\x32\x14.EBroadcastImageType:\x1ak_EBroadcastImageType_NoneB\x13\x82\xb5\x18\x0f\x45\x42roadcastImage\x12]\n\x0bimage_index\x18\x03 \x01(\rBH\x82\xb5\x18\x44Index of the image (for supporting multiple uploads of the same type\x12(\n\x0bimage_width\x18\x04 \x01(\rB\x13\x82\xb5\x18\x0fwidth in pixels\x12*\n\x0cimage_height\x18\x05 \x01(\rB\x14\x82\xb5\x18\x10height in pixels\x12\x1f\n\tfile_size\x18\x06 \x01(\rB\x0c\x82\xb5\x18\x08in bytes\x12#\n\x0e\x66ile_extension\x18\x07 \x01(\tB\x0b\x82\xb5\x18\x07\x65g .jpg\x12 \n\tfile_hash\x18\x08 \x01(\tB\r\x82\xb5\x18\timage SHA\x12\x34\n\x04undo\x18\t \x01(\x08\x42&\x82\xb5\x18\"indicates this is a delete request\"\x86\x01\n*CSteamTV_SetBroadcastChannelImage_Response\x12X\n\x12replace_image_hash\x18\x01 \x01(\tB<\x82\xb5\x18\x38set if caller should remove previous SHA file from cache\"\xac\x01\n*CSteamTV_GetBroadcastChannelImages_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\x12\x46\n\x0bimage_types\x18\x02 \x03(\x0e\x32\x14.EBroadcastImageTypeB\x1b\x82\xb5\x18\x17list of EBroadcastImage\"\xbb\x02\n+CSteamTV_GetBroadcastChannelImages_Response\x12\x43\n\x06images\x18\x01 \x03(\x0b\x32\x33.CSteamTV_GetBroadcastChannelImages_Response.Images\x1a\xc6\x01\n\x06Images\x12[\n\nimage_type\x18\x01 \x01(\x0e\x32\x14.EBroadcastImageType:\x1ak_EBroadcastImageType_NoneB\x15\x82\xb5\x18\x11Type of the image\x12\x32\n\nimage_path\x18\x02 \x01(\tB\x1e\x82\xb5\x18\x1aPath to the uploaded image\x12+\n\x0bimage_index\x18\x03 \x01(\rB\x16\x82\xb5\x18\x12Index of the image\"\x86\x05\n/CSteamTV_SetBroadcastChannelLinkRegions_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\x12\x45\n\x05links\x18\x02 \x03(\x0b\x32\x36.CSteamTV_SetBroadcastChannelLinkRegions_Request.Links\x1a\xd3\x03\n\x05Links\x12L\n\nlink_index\x18\x01 \x01(\rB8\x82\xb5\x18\x34Index of the link (lower number has higher priority)\x12\x15\n\x03url\x18\x02 \x01(\tB\x08\x82\xb5\x18\x04URL \x12O\n\x10link_description\x18\x03 \x01(\tB5\x82\xb5\x18\x31URL description that will show in the link region\x12\x44\n\x04left\x18\x04 \x01(\rB6\x82\xb5\x18\x32Left X position in 100th of a % of the video width\x12\x43\n\x03top\x18\x05 \x01(\rB6\x82\xb5\x18\x32Top Y position in 100th of a % of the video height\x12\x42\n\x05width\x18\x06 \x01(\rB3\x82\xb5\x18/Region Width in 100th of a % of the video width\x12\x45\n\x06height\x18\x07 \x01(\rB5\x82\xb5\x18\x31Region Height in 100th of a % of the video height\"2\n0CSteamTV_SetBroadcastChannelLinkRegions_Response\"c\n)CSteamTV_GetBroadcastChannelLinks_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\"\xc4\x04\n*CSteamTV_GetBroadcastChannelLinks_Response\x12@\n\x05links\x18\x01 \x03(\x0b\x32\x31.CSteamTV_GetBroadcastChannelLinks_Response.Links\x1a\xd3\x03\n\x05Links\x12L\n\nlink_index\x18\x01 \x01(\rB8\x82\xb5\x18\x34Index of the link (lower number has higher priority)\x12\x15\n\x03url\x18\x02 \x01(\tB\x08\x82\xb5\x18\x04URL \x12O\n\x10link_description\x18\x03 \x01(\tB5\x82\xb5\x18\x31URL description that will show in the link region\x12\x44\n\x04left\x18\x04 \x01(\rB6\x82\xb5\x18\x32Left X position in 100th of a % of the video width\x12\x43\n\x03top\x18\x05 \x01(\rB6\x82\xb5\x18\x32Top Y position in 100th of a % of the video height\x12\x42\n\x05width\x18\x06 \x01(\rB3\x82\xb5\x18/Region Width in 100th of a % of the video width\x12\x45\n\x06height\x18\x07 \x01(\rB5\x82\xb5\x18\x31Region Height in 100th of a % of the video height\"j\n0CSteamTV_GetBroadcastChannelBroadcasters_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\"\x9a\x02\n1CSteamTV_GetBroadcastChannelBroadcasters_Response\x12T\n\x0c\x62roadcasters\x18\x01 \x03(\x0b\x32>.CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster\x1a\x8e\x01\n\x0b\x42roadcaster\x12)\n\x07steamid\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcaster Steam ID\x12\"\n\x04name\x18\x02 \x01(\tB\x14\x82\xb5\x18\x10\x42roadcaster name\x12\x30\n\nrtmp_token\x18\x03 \x01(\tB\x1c\x82\xb5\x18\x18\x42roadcaster upload token\"&\n$CSteamTV_GetFollowedChannels_Request\"\xb1\x08\n\x18GetBroadcastChannelEntry\x12;\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x1d\x82\xb5\x18\x19\x42roadcast channel ID or 0\x12>\n\x0bunique_name\x18\x02 \x01(\tB)\x82\xb5\x18%Unique broadcast channel name for URL\x12-\n\x04name\x18\x03 \x01(\tB\x1f\x82\xb5\x18\x1bLong broadcast channel name\x12\x43\n\x05\x61ppid\x18\x04 \x01(\rB4\x82\xb5\x18\x30The game ID the requested broadcaster is playing\x12\x39\n\x07viewers\x18\x05 \x01(\x04\x42(\x82\xb5\x18$Number of viewers currently watching\x12\x38\n\x05views\x18\x06 \x01(\x04\x42)\x82\xb5\x18%Number of total views of this channel\x12\x30\n\rthumbnail_url\x18\x07 \x01(\tB\x19\x82\xb5\x18\x15\x43urrent thumbnail URL\x12:\n\tfollowers\x18\x08 \x01(\x04\x42\'\x82\xb5\x18#Number of followers of this channel\x12/\n\x08headline\x18\t \x01(\tB\x1d\x82\xb5\x18\x19short channel description\x12,\n\navatar_url\x18\n \x01(\tB\x18\x82\xb5\x18\x14\x63ommunity avatar url\x12>\n\x13\x62roadcaster_steamid\x18\x0b \x01(\x06\x42!\x82\xb5\x18\x1d\x43urrent broadcaster streaming\x12>\n\x0bsubscribers\x18\x0c \x01(\x04\x42)\x82\xb5\x18%Number of subscribers of this channel\x12\x30\n\x0e\x62\x61\x63kground_url\x18\r \x01(\tB\x18\x82\xb5\x18\x14\x42\x61\x63kground image url\x12\x38\n\x0bis_featured\x18\x0e \x01(\x08\x42#\x82\xb5\x18\x1fWhether the channel is featured\x12\x38\n\x0bis_disabled\x18\x0f \x01(\x08\x42#\x82\xb5\x18\x1fWhether the channel is disabled\x12\x35\n\x07is_live\x18\x10 \x01(\x08\x42$\x82\xb5\x18 Whether the channel is streaming\x12\x33\n\x08language\x18\x11 \x01(\tB!\x82\xb5\x18\x1dThe language the stream is in\x12:\n\x07reports\x18\x12 \x01(\rB)\x82\xb5\x18%The number of reports the channel has\x12\x14\n\x0cis_partnered\x18\x13 \x01(\x08\"q\n%CSteamTV_GetFollowedChannels_Response\x12H\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntryB\x1c\x82\xb5\x18\x18The list of broadcasters\"(\n&CSteamTV_GetSubscribedChannels_Request\"s\n\'CSteamTV_GetSubscribedChannels_Response\x12H\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntryB\x1c\x82\xb5\x18\x18The list of broadcasters\"d\n*CSteamTV_GetBroadcastChannelStatus_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\"\x93\x05\n+CSteamTV_GetBroadcastChannelStatus_Response\x12?\n\x07is_live\x18\x01 \x01(\x08\x42.\x82\xb5\x18*Indicates whether the channel is streaming\x12H\n\x0bis_disabled\x18\x02 \x01(\x08\x42\x33\x82\xb5\x18/Indicates whether the channel has been disabled\x12\x43\n\x05\x61ppid\x18\x03 \x01(\rB4\x82\xb5\x18\x30The game ID the requested broadcaster is playing\x12\x39\n\x07viewers\x18\x04 \x01(\x04\x42(\x82\xb5\x18$Number of viewers currently watching\x12\x38\n\x05views\x18\x05 \x01(\x04\x42)\x82\xb5\x18%Number of total views of this channel\x12>\n\x13\x62roadcaster_steamid\x18\x06 \x01(\x06\x42!\x82\xb5\x18\x1d\x43urrent broadcaster streaming\x12\x30\n\rthumbnail_url\x18\x07 \x01(\tB\x19\x82\xb5\x18\x15\x43urrent thumbnail URL\x12:\n\tfollowers\x18\x08 \x01(\x04\x42\'\x82\xb5\x18#Number of followers of this channel\x12>\n\x0bsubscribers\x18\t \x01(\x04\x42)\x82\xb5\x18%Number of subscribers of this channel\x12\x13\n\x0bunique_name\x18\n \x01(\t\x12\x1c\n\x14\x62roadcast_session_id\x18\x0b \x01(\x04\"\x9a\x01\n\'CSteamTV_FollowBroadcastChannel_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\x12\x37\n\x04undo\x18\x02 \x01(\x08\x42)\x82\xb5\x18%Indicates this is an unfollow request\"f\n(CSteamTV_FollowBroadcastChannel_Response\x12:\n\x0bis_followed\x18\x01 \x01(\x08\x42%\x82\xb5\x18!Whether the user is now following\"d\n*CSteamTV_SubscribeBroadcastChannel_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\"l\n+CSteamTV_SubscribeBroadcastChannel_Response\x12=\n\ris_subscribed\x18\x01 \x01(\x08\x42&\x82\xb5\x18\"Whether the user is now subscribed\"I\n)CSteamTV_GetBroadcastChannelClips_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"\x8a\x04\n\x1a\x43SteamTV_BroadcastClipInfo\x12\x30\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x42\x15\x82\xb5\x18\x11\x62roadcast clip ID\x12,\n\nchannel_id\x18\x02 \x01(\x04\x42\x18\x82\xb5\x18\x14\x42roadcast Channel ID\x12\x30\n\x06\x61pp_id\x18\x03 \x01(\rB \x82\xb5\x18\x1c\x41pp ID stream is tagged with\x12\x34\n\x13\x62roadcaster_steamid\x18\x04 \x01(\x06\x42\x17\x82\xb5\x18\x13\x42roadcaster SteamID\x12/\n\x0f\x63reator_steamid\x18\x05 \x01(\x06\x42\x16\x82\xb5\x18\x12\x43lip-maker SteamID\x12\x45\n\x11video_description\x18\x06 \x01(\tB*\x82\xb5\x18&Short name or description of this clip\x12\x39\n\tlive_time\x18\x07 \x01(\rB&\x82\xb5\x18\"GMT time clip was broadcasted live\x12,\n\tlength_ms\x18\x08 \x01(\rB\x19\x82\xb5\x18\x15length of video in MS\x12\x43\n\x0ethumbnail_path\x18\t \x01(\tB+\x82\xb5\x18\'relative path for thumbnail URL on host\"p\n*CSteamTV_GetBroadcastChannelClips_Response\x12*\n\x05\x63lips\x18\x01 \x03(\x0b\x32\x1b.CSteamTV_BroadcastClipInfo\x12\x16\n\x0ethumbnail_host\x18\x02 \x01(\t\"\x90\x01\n\'CSteamTV_ReportBroadcastChannel_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\x12-\n\x06reason\x18\x02 \x01(\tB\x1d\x82\xb5\x18\x19The reason for the report\"*\n(CSteamTV_ReportBroadcastChannel_Response\"i\n/CSteamTV_GetBroadcastChannelInteraction_Request\x12\x36\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x42\x18\x82\xb5\x18\x14\x42roadcast channel ID\"\xc3\x01\n0CSteamTV_GetBroadcastChannelInteraction_Response\x12\x43\n\x0bis_followed\x18\x01 \x01(\x08\x42.\x82\xb5\x18*Whether the user has followed this channel\x12J\n\ris_subscribed\x18\x02 \x01(\x08\x42\x33\x82\xb5\x18/Whether the user has subscribed to this channel\"\xfc\x01\n\x19\x43SteamTV_GetGames_Request\x12&\n\x05\x61ppid\x18\x01 \x01(\rB\x17\x82\xb5\x18\x13The ID for the game\x12{\n\talgorithm\x18\x02 \x01(\x0e\x32\x13.EGetGamesAlgorithm:\x1ck_EGetGamesAlgorithm_DefaultB5\x82\xb5\x18\x31The algorithm to use when picking games to return\x12:\n\x05\x63ount\x18\x03 \x01(\rB+\x82\xb5\x18\'The maximum number of results to return\"\xd5\x02\n\rCSteamTV_Game\x12&\n\x05\x61ppid\x18\x01 \x01(\rB\x17\x82\xb5\x18\x13The ID for the game\x12\'\n\x04name\x18\x02 \x01(\tB\x19\x82\xb5\x18\x15The name for the game\x12)\n\x05image\x18\x03 \x01(\tB\x1a\x82\xb5\x18\x16The image for the game\x12\x38\n\x07viewers\x18\x04 \x01(\x04\x42\'\x82\xb5\x18#Number of people watching this game\x12R\n\x08\x63hannels\x18\x05 \x03(\x0b\x32\x19.GetBroadcastChannelEntryB%\x82\xb5\x18!Live channels streaming this game\x12\x14\n\x0crelease_date\x18\x06 \x01(\t\x12\x11\n\tdeveloper\x18\x07 \x01(\t\x12\x11\n\tpublisher\x18\x08 \x01(\t\"T\n\x1a\x43SteamTV_GetGames_Response\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32\x0e.CSteamTV_GameB\x15\x82\xb5\x18\x11The list of games\"\x97\x02\n\x1c\x43SteamTV_GetChannels_Request\x12\x84\x01\n\talgorithm\x18\x01 \x01(\x0e\x32\x16.EGetChannelsAlgorithm:\x1fk_EGetChannelsAlgorithm_DefaultB8\x82\xb5\x18\x34The algorithm to use when picking channels to return\x12:\n\x05\x63ount\x18\x02 \x01(\rB+\x82\xb5\x18\'The maximum number of results to return\x12\x34\n\x05\x61ppid\x18\x03 \x01(\rB%\x82\xb5\x18!Filter results to only this appid\"r\n\x1d\x43SteamTV_GetChannels_Response\x12Q\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntryB%\x82\xb5\x18!The list of featured broadcasters\"\x87\x01\n\x1b\x43SteamTV_AddChatBan_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hatter_steamid\x18\x02 \x01(\x06\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x11\n\tpermanent\x18\x04 \x01(\x08\x12\x0c\n\x04undo\x18\x05 \x01(\x08\"\x1e\n\x1c\x43SteamTV_AddChatBan_Response\"<\n\x1c\x43SteamTV_GetChatBans_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"z\n\x10\x43SteamTV_ChatBan\x12\x16\n\x0eissuer_steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hatter_steamid\x18\x02 \x01(\x06\x12\x14\n\x0ctime_expires\x18\x03 \x01(\t\x12\x11\n\tpermanent\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\"Y\n\x1d\x43SteamTV_GetChatBans_Response\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\x11.CSteamTV_ChatBanB\x14\x82\xb5\x18\x10The list of bans\"j\n!CSteamTV_AddChatModerator_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x19\n\x11moderator_steamid\x18\x02 \x01(\x06\x12\x0c\n\x04undo\x18\x03 \x01(\x08\"$\n\"CSteamTV_AddChatModerator_Response\"B\n\"CSteamTV_GetChatModerators_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"7\n\x16\x43SteamTV_ChatModerator\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\"k\n#CSteamTV_GetChatModerators_Response\x12\x44\n\x07results\x18\x01 \x03(\x0b\x32\x17.CSteamTV_ChatModeratorB\x1a\x82\xb5\x18\x16The list of moderators\"W\n\x1b\x43SteamTV_AddWordBan_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x0c\n\x04word\x18\x02 \x01(\t\x12\x0c\n\x04undo\x18\x03 \x01(\x08\"\x1e\n\x1c\x43SteamTV_AddWordBan_Response\"<\n\x1c\x43SteamTV_GetWordBans_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"N\n\x1d\x43SteamTV_GetWordBans_Response\x12-\n\x07results\x18\x01 \x03(\tB\x1c\x82\xb5\x18\x18The list of banned words\"9\n\x19\x43SteamTV_JoinChat_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"a\n\x1a\x43SteamTV_JoinChat_Response\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x19\n\x11view_url_template\x18\x02 \x01(\t\x12\x17\n\x0f\x66lair_group_ids\x18\x03 \x03(\x04\"\'\n\x17\x43SteamTV_Search_Request\x12\x0c\n\x04term\x18\x01 \x01(\t\"d\n\x18\x43SteamTV_Search_Response\x12H\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntryB\x1c\x82\xb5\x18\x18The list of broadcasters\")\n\'CSteamTV_GetSteamTVUserSettings_Request\"\xcc\x01\n(CSteamTV_GetSteamTVUserSettings_Response\x12\x45\n\x11stream_live_email\x18\x01 \x01(\x08\x42*\x82\xb5\x18&Send email when followed stream starts\x12Y\n\x18stream_live_notification\x18\x02 \x01(\x08\x42\x37\x82\xb5\x18\x33Send Steam notification when followed stream starts\"\xcb\x01\n\'CSteamTV_SetSteamTVUserSettings_Request\x12\x45\n\x11stream_live_email\x18\x01 \x01(\x08\x42*\x82\xb5\x18&Send email when followed stream starts\x12Y\n\x18stream_live_notification\x18\x02 \x01(\x08\x42\x37\x82\xb5\x18\x33Send Steam notification when followed stream starts\"*\n(CSteamTV_SetSteamTVUserSettings_Response\")\n\'CSteamTV_GetMyBroadcastChannels_Request\"t\n(CSteamTV_GetMyBroadcastChannels_Response\x12H\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntryB\x1c\x82\xb5\x18\x18The list of broadcasters\"&\n$CSteamTV_GetHomePageContents_Request\"S\n\"CSteamTV_HomePageTemplate_Takeover\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"s\n$CSteamTV_HomePageTemplate_SingleGame\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\r\n\x05title\x18\x03 \x01(\t\"_\n\rGameListEntry\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tgame_name\x18\x02 \x01(\t\x12,\n\tbroadcast\x18\x03 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\"T\n\"CSteamTV_HomePageTemplate_GameList\x12\x1f\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x0e.GameListEntry\x12\r\n\x05title\x18\x02 \x01(\t\"f\n&CSteamTV_HomePageTemplate_QuickExplore\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"f\n&CSteamTV_HomePageTemplate_ConveyorBelt\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"z\n$CSteamTV_HomePageTemplate_WatchParty\x12,\n\tbroadcast\x18\x01 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\x12\x15\n\rchat_group_id\x18\x03 \x01(\x04\"b\n#CSteamTV_HomePageTemplate_Developer\x12,\n\tbroadcast\x18\x01 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"0\n\x1f\x43SteamTV_HomePageTemplate_Event\x12\r\n\x05title\x18\x01 \x01(\t\"\xc2\x04\n\x1b\x43SteamTV_HomePageContentRow\x12R\n\rtemplate_type\x18\x01 \x01(\x0e\x32\x18.ESteamTVContentTemplate:!k_ESteamTVContentTemplate_Invalid\x12\x35\n\x08takeover\x18\x02 \x01(\x0b\x32#.CSteamTV_HomePageTemplate_Takeover\x12:\n\x0bsingle_game\x18\x03 \x01(\x0b\x32%.CSteamTV_HomePageTemplate_SingleGame\x12\x36\n\tgame_list\x18\x04 \x01(\x0b\x32#.CSteamTV_HomePageTemplate_GameList\x12>\n\rquick_explore\x18\x05 \x01(\x0b\x32\'.CSteamTV_HomePageTemplate_QuickExplore\x12>\n\rconveyor_belt\x18\x06 \x01(\x0b\x32\'.CSteamTV_HomePageTemplate_ConveyorBelt\x12:\n\x0bwatch_party\x18\x07 \x01(\x0b\x32%.CSteamTV_HomePageTemplate_WatchParty\x12\x37\n\tdeveloper\x18\x08 \x01(\x0b\x32$.CSteamTV_HomePageTemplate_Developer\x12/\n\x05\x65vent\x18\t \x01(\x0b\x32 .CSteamTV_HomePageTemplate_Event\"S\n%CSteamTV_GetHomePageContents_Response\x12*\n\x04rows\x18\x01 \x03(\x0b\x32\x1c.CSteamTV_HomePageContentRow\"\xb6\x01\n!CSteamTV_AppCheer_SingleCheerType\x12`\n\ncheer_type\x18\x01 \x01(\rBL\x82\xb5\x18HThe type of cheer. App dependent (different teams, heroes, players, etc)\x12/\n\x0c\x63heer_amount\x18\x02 \x01(\rB\x19\x82\xb5\x18\x15The amount of cheers.\"\xde\x02\n\x19\x43SteamTV_AppCheer_Request\x12-\n\x06\x61pp_id\x18\x01 \x01(\rB\x1d\x82\xb5\x18\x19\x41pp ID this cheer is for.\x12\x85\x01\n\x0f\x63heer_target_id\x18\x02 \x01(\x06\x42l\x82\xb5\x18hThe thing being cheered on. ID is app dependent (could be steam id, match id, lobby id, server id, etc).\x12\x89\x01\n\x06\x63heers\x18\x03 \x03(\x0b\x32\".CSteamTV_AppCheer_SingleCheerTypeBU\x82\xb5\x18QThe set of cheers this request represents (could be multiple of different types).\"\xef\x01\n\x1a\x43SteamTV_AppCheer_Response\x12\xd0\x01\n\x14\x61ggregation_delay_ms\x18\x01 \x01(\rB\xb1\x01\x82\xb5\x18\xac\x01The amount of time in milliseconds that the client should aggregate cheers before sending them. The server can control this dynamically to ask clients to slow down sending.*\x8a\x02\n\x13\x45\x42roadcastImageType\x12\x1e\n\x1ak_EBroadcastImageType_None\x10\x00\x12!\n\x1dk_EBroadcastImageType_Offline\x10\x01\x12!\n\x1dk_EBroadcastImageType_Standby\x10\x02\x12 \n\x1ck_EBroadcastImageType_Avatar\x10\x03\x12!\n\x1dk_EBroadcastImageType_Summary\x10\x04\x12$\n k_EBroadcastImageType_Background\x10\x05\x12\"\n\x1ek_EBroadcastImageType_Emoticon\x10\x06*\x80\x01\n\x12\x45GetGamesAlgorithm\x12 \n\x1ck_EGetGamesAlgorithm_Default\x10\x01\x12#\n\x1fk_EGetGamesAlgorithm_MostPlayed\x10\x02\x12#\n\x1fk_EGetGamesAlgorithm_PopularNew\x10\x03*\xd5\x01\n\x15\x45GetChannelsAlgorithm\x12#\n\x1fk_EGetChannelsAlgorithm_Default\x10\x01\x12#\n\x1fk_EGetChannelsAlgorithm_Friends\x10\x02\x12$\n k_EGetChannelsAlgorithm_Featured\x10\x03\x12%\n!k_EGetChannelsAlgorithm_Developer\x10\x04\x12%\n!k_EGetChannelsAlgorithm_Following\x10\x05*\x8a\x03\n\x17\x45SteamTVContentTemplate\x12%\n!k_ESteamTVContentTemplate_Invalid\x10\x00\x12&\n\"k_ESteamTVContentTemplate_Takeover\x10\x01\x12(\n$k_ESteamTVContentTemplate_SingleGame\x10\x02\x12&\n\"k_ESteamTVContentTemplate_GameList\x10\x03\x12*\n&k_ESteamTVContentTemplate_QuickExplore\x10\x04\x12*\n&k_ESteamTVContentTemplate_ConveyorBelt\x10\x05\x12(\n$k_ESteamTVContentTemplate_WatchParty\x10\x06\x12\'\n#k_ESteamTVContentTemplate_Developer\x10\x07\x12#\n\x1fk_ESteamTVContentTemplate_Event\x10\x08\x32\xbf&\n\x07SteamTV\x12\x8e\x01\n\x16\x43reateBroadcastChannel\x12(.CSteamTV_CreateBroadcastChannel_Request\x1a).CSteamTV_CreateBroadcastChannel_Response\"\x1f\x82\xb5\x18\x1b\x43reate a channel on SteamTV\x12\xb1\x01\n\x15GetBroadcastChannelID\x12\'.CSteamTV_GetBroadcastChannelID_Request\x1a(.CSteamTV_GetBroadcastChannelID_Response\"E\x82\xb5\x18\x41Get a broadcast channel ID for a channel by name or owner SteamID\x12\xa1\x01\n\x1aSetBroadcastChannelProfile\x12,.CSteamTV_SetBroadcastChannelProfile_Request\x1a-.CSteamTV_SetBroadcastChannelProfile_Response\"&\x82\xb5\x18\"Set broadcast channel profile data\x12\xa1\x01\n\x1aGetBroadcastChannelProfile\x12,.CSteamTV_GetBroadcastChannelProfile_Request\x1a-.CSteamTV_GetBroadcastChannelProfile_Response\"&\x82\xb5\x18\"Get broadcast channel profile data\x12\x99\x01\n\x18SetBroadcastChannelImage\x12*.CSteamTV_SetBroadcastChannelImage_Request\x1a+.CSteamTV_SetBroadcastChannelImage_Response\"$\x82\xb5\x18 Set broadcast channel image hash\x12\x98\x01\n\x19GetBroadcastChannelImages\x12+.CSteamTV_GetBroadcastChannelImages_Request\x1a,.CSteamTV_GetBroadcastChannelImages_Response\" \x82\xb5\x18\x1cGet broadcast channel images\x12\xad\x01\n\x1eSetBroadcastChannelLinkRegions\x12\x30.CSteamTV_SetBroadcastChannelLinkRegions_Request\x1a\x31.CSteamTV_SetBroadcastChannelLinkRegions_Response\"&\x82\xb5\x18\"Set broadcast channel link regions\x12\x9b\x01\n\x18GetBroadcastChannelLinks\x12*.CSteamTV_GetBroadcastChannelLinks_Request\x1a+.CSteamTV_GetBroadcastChannelLinks_Response\"&\x82\xb5\x18\"Get broadcast channel link regions\x12\xbb\x01\n\x1fGetBroadcastChannelBroadcasters\x12\x31.CSteamTV_GetBroadcastChannelBroadcasters_Request\x1a\x32.CSteamTV_GetBroadcastChannelBroadcasters_Response\"1\x82\xb5\x18-Get list of broadcaster info for this channel\x12\x93\x01\n\x13GetFollowedChannels\x12%.CSteamTV_GetFollowedChannels_Request\x1a&.CSteamTV_GetFollowedChannels_Response\"-\x82\xb5\x18)Get list of followed channels by a viewer\x12\x9c\x01\n\x15GetSubscribedChannels\x12\'.CSteamTV_GetSubscribedChannels_Request\x1a(.CSteamTV_GetSubscribedChannels_Response\"0\x82\xb5\x18,Get list of channels a user is subscribed to\x12\x9d\x01\n\x19GetBroadcastChannelStatus\x12+.CSteamTV_GetBroadcastChannelStatus_Request\x1a,.CSteamTV_GetBroadcastChannelStatus_Response\"%\x82\xb5\x18!Get broadcast channel live status\x12\x8d\x01\n\x16\x46ollowBroadcastChannel\x12(.CSteamTV_FollowBroadcastChannel_Request\x1a).CSteamTV_FollowBroadcastChannel_Response\"\x1e\x82\xb5\x18\x1a\x46ollow a broadcast channel\x12\x9c\x01\n\x19SubscribeBroadcastChannel\x12+.CSteamTV_SubscribeBroadcastChannel_Request\x1a,.CSteamTV_SubscribeBroadcastChannel_Response\"$\x82\xb5\x18 Subscribe to a broadcast channel\x12\x94\x01\n\x18GetBroadcastChannelClips\x12*.CSteamTV_GetBroadcastChannelClips_Request\x1a+.CSteamTV_GetBroadcastChannelClips_Response\"\x1f\x82\xb5\x18\x1bGet broadcast channel clips\x12\x8d\x01\n\x16ReportBroadcastChannel\x12(.CSteamTV_ReportBroadcastChannel_Request\x1a).CSteamTV_ReportBroadcastChannel_Response\"\x1e\x82\xb5\x18\x1aReport a broadcast channel\x12\xc1\x01\n\x1eGetBroadcastChannelInteraction\x12\x30.CSteamTV_GetBroadcastChannelInteraction_Request\x1a\x31.CSteamTV_GetBroadcastChannelInteraction_Response\":\x82\xb5\x18\x36Get user\'s interaction status with a broadcast channel\x12s\n\x08GetGames\x12\x1a.CSteamTV_GetGames_Request\x1a\x1b.CSteamTV_GetGames_Response\".\x82\xb5\x18*Get list of games with active broadcasters\x12}\n\x0bGetChannels\x12\x1d.CSteamTV_GetChannels_Request\x1a\x1e.CSteamTV_GetChannels_Response\"/\x82\xb5\x18+Get the list of featured broadcast channels\x12\xa0\x01\n\nAddChatBan\x12\x1c.CSteamTV_AddChatBan_Request\x1a\x1d.CSteamTV_AddChatBan_Response\"U\x82\xb5\x18QSet the ban for a specific broadcaster. The issuer is the logged in steam account\x12\x7f\n\x0bGetChatBans\x12\x1d.CSteamTV_GetChatBans_Request\x1a\x1e.CSteamTV_GetChatBans_Response\"1\x82\xb5\x18-Get list of bans for a specific broadcaster. \x12\x95\x01\n\x10\x41\x64\x64\x43hatModerator\x12\".CSteamTV_AddChatModerator_Request\x1a#.CSteamTV_AddChatModerator_Response\"8\x82\xb5\x18\x34\x41\x64\x64 or remove a moderator for this broadcast channel\x12\x9d\x01\n\x11GetChatModerators\x12#.CSteamTV_GetChatModerators_Request\x1a$.CSteamTV_GetChatModerators_Response\"=\x82\xb5\x18\x39Returns the list of moderators for this broadcast channel\x12\x8c\x01\n\nAddWordBan\x12\x1c.CSteamTV_AddWordBan_Request\x1a\x1d.CSteamTV_AddWordBan_Response\"A\x82\xb5\x18=Add or remove a banned keyword in this broadcast channel chat\x12\x90\x01\n\x0bGetWordBans\x12\x1d.CSteamTV_GetWordBans_Request\x1a\x1e.CSteamTV_GetWordBans_Response\"B\x82\xb5\x18>Returns the list of banned keywords for this broadcast channel\x12o\n\x08JoinChat\x12\x1a.CSteamTV_JoinChat_Request\x1a\x1b.CSteamTV_JoinChat_Response\"*\x82\xb5\x18&Joins the chat channel for a broadcast\x12z\n\x06Search\x12\x18.CSteamTV_Search_Request\x1a\x19.CSteamTV_Search_Response\";\x82\xb5\x18\x37Searches for broadcast channels based on input keywords\x12\x94\x01\n\x16GetSteamTVUserSettings\x12(.CSteamTV_GetSteamTVUserSettings_Request\x1a).CSteamTV_GetSteamTVUserSettings_Response\"%\x82\xb5\x18!Returns a user\'s SteamTV settings\x12\x91\x01\n\x16SetSteamTVUserSettings\x12(.CSteamTV_SetSteamTVUserSettings_Request\x1a).CSteamTV_SetSteamTVUserSettings_Response\"\"\x82\xb5\x18\x1eSets a user\'s SteamTV settings\x12\xa9\x01\n\x16GetMyBroadcastChannels\x12(.CSteamTV_GetMyBroadcastChannels_Request\x1a).CSteamTV_GetMyBroadcastChannels_Response\":\x82\xb5\x18\x36Gets the broadcast channels that the current user owns\x12\x8c\x01\n\x13GetHomePageContents\x12%.CSteamTV_GetHomePageContents_Request\x1a&.CSteamTV_GetHomePageContents_Response\"&\x82\xb5\x18\"Returns homepage contents for user\x12\x8a\x01\n\x08\x41ppCheer\x12\x1a.CSteamTV_AppCheer_Request\x1a\x1b.CSteamTV_AppCheer_Response\"E\x82\xb5\x18\x41The user is cheering for a specific broadcast for a specific app.\x1a#\x82\xb5\x18\x1fMethods for Steam TV operationsB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_EBROADCASTIMAGETYPE = _descriptor.EnumDescriptor(
  name='EBroadcastImageType',
  full_name='EBroadcastImageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastImageType_None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastImageType_Offline', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastImageType_Standby', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastImageType_Avatar', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastImageType_Summary', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastImageType_Background', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EBroadcastImageType_Emoticon', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14109,
  serialized_end=14375,
)
_sym_db.RegisterEnumDescriptor(_EBROADCASTIMAGETYPE)

EBroadcastImageType = enum_type_wrapper.EnumTypeWrapper(_EBROADCASTIMAGETYPE)
_EGETGAMESALGORITHM = _descriptor.EnumDescriptor(
  name='EGetGamesAlgorithm',
  full_name='EGetGamesAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGetGamesAlgorithm_Default', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGetGamesAlgorithm_MostPlayed', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGetGamesAlgorithm_PopularNew', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14378,
  serialized_end=14506,
)
_sym_db.RegisterEnumDescriptor(_EGETGAMESALGORITHM)

EGetGamesAlgorithm = enum_type_wrapper.EnumTypeWrapper(_EGETGAMESALGORITHM)
_EGETCHANNELSALGORITHM = _descriptor.EnumDescriptor(
  name='EGetChannelsAlgorithm',
  full_name='EGetChannelsAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGetChannelsAlgorithm_Default', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGetChannelsAlgorithm_Friends', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGetChannelsAlgorithm_Featured', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGetChannelsAlgorithm_Developer', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EGetChannelsAlgorithm_Following', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14509,
  serialized_end=14722,
)
_sym_db.RegisterEnumDescriptor(_EGETCHANNELSALGORITHM)

EGetChannelsAlgorithm = enum_type_wrapper.EnumTypeWrapper(_EGETCHANNELSALGORITHM)
_ESTEAMTVCONTENTTEMPLATE = _descriptor.EnumDescriptor(
  name='ESteamTVContentTemplate',
  full_name='ESteamTVContentTemplate',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_Takeover', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_SingleGame', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_GameList', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_QuickExplore', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_ConveyorBelt', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_WatchParty', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_Developer', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamTVContentTemplate_Event', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14725,
  serialized_end=15119,
)
_sym_db.RegisterEnumDescriptor(_ESTEAMTVCONTENTTEMPLATE)

ESteamTVContentTemplate = enum_type_wrapper.EnumTypeWrapper(_ESTEAMTVCONTENTTEMPLATE)
k_EBroadcastImageType_None = 0
k_EBroadcastImageType_Offline = 1
k_EBroadcastImageType_Standby = 2
k_EBroadcastImageType_Avatar = 3
k_EBroadcastImageType_Summary = 4
k_EBroadcastImageType_Background = 5
k_EBroadcastImageType_Emoticon = 6
k_EGetGamesAlgorithm_Default = 1
k_EGetGamesAlgorithm_MostPlayed = 2
k_EGetGamesAlgorithm_PopularNew = 3
k_EGetChannelsAlgorithm_Default = 1
k_EGetChannelsAlgorithm_Friends = 2
k_EGetChannelsAlgorithm_Featured = 3
k_EGetChannelsAlgorithm_Developer = 4
k_EGetChannelsAlgorithm_Following = 5
k_ESteamTVContentTemplate_Invalid = 0
k_ESteamTVContentTemplate_Takeover = 1
k_ESteamTVContentTemplate_SingleGame = 2
k_ESteamTVContentTemplate_GameList = 3
k_ESteamTVContentTemplate_QuickExplore = 4
k_ESteamTVContentTemplate_ConveyorBelt = 5
k_ESteamTVContentTemplate_WatchParty = 6
k_ESteamTVContentTemplate_Developer = 7
k_ESteamTVContentTemplate_Event = 8



_CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_CreateBroadcastChannel_Request',
  full_name='CSteamTV_CreateBroadcastChannel_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='CSteamTV_CreateBroadcastChannel_Request.unique_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309Unique short broadcast channel name, part of Steam.TV URL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=216,
)


_CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_CreateBroadcastChannel_Response',
  full_name='CSteamTV_CreateBroadcastChannel_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_CreateBroadcastChannel_Response.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031Broadcast channel ID or 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=321,
)


_CSTEAMTV_GETBROADCASTCHANNELID_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelID_Request',
  full_name='CSteamTV_GetBroadcastChannelID_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='CSteamTV_GetBroadcastChannelID_Request.unique_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Channel short name)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=409,
)


_CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelID_Response',
  full_name='CSteamTV_GetBroadcastChannelID_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelID_Response.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031Broadcast channel ID or 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='CSteamTV_GetBroadcastChannelID_Response.unique_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\026Broadcast channel name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSteamTV_GetBroadcastChannelID_Response.steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027Broadcast channel owner', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=609,
)


_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelProfile_Request',
  full_name='CSteamTV_SetBroadcastChannelProfile_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_SetBroadcastChannelProfile_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_SetBroadcastChannelProfile_Request.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021long channel name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CSteamTV_SetBroadcastChannelProfile_Request.language', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*primary channel language (Steam shortname)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headline', full_name='CSteamTV_SetBroadcastChannelProfile_Request.headline', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030short channel desciption', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='CSteamTV_SetBroadcastChannelProfile_Request.summary', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027long channel desciption', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_hash', full_name='CSteamTV_SetBroadcastChannelProfile_Request.avatar_hash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025community avatar hash', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='CSteamTV_SetBroadcastChannelProfile_Request.schedule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032broadcast channel schedule', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='CSteamTV_SetBroadcastChannelProfile_Request.rules', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027broadcast channel rules', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='panels', full_name='CSteamTV_SetBroadcastChannelProfile_Request.panels', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030/JSON data representing the channel panel layout', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=1121,
)


_CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelProfile_Response',
  full_name='CSteamTV_SetBroadcastChannelProfile_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1169,
)


_CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelProfile_Request',
  full_name='CSteamTV_GetBroadcastChannelProfile_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelProfile_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1272,
)


_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelProfile_Response',
  full_name='CSteamTV_GetBroadcastChannelProfile_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='CSteamTV_GetBroadcastChannelProfile_Response.unique_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309Unique short broadcast channel name, part of Steam.TV URL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_steamid', full_name='CSteamTV_GetBroadcastChannelProfile_Response.owner_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027Broadcast channel owner', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_GetBroadcastChannelProfile_Response.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021long channel name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CSteamTV_GetBroadcastChannelProfile_Response.language', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*primary channel language (Steam shortname)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headline', full_name='CSteamTV_GetBroadcastChannelProfile_Response.headline', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031short channel description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='CSteamTV_GetBroadcastChannelProfile_Response.summary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030long channel description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='CSteamTV_GetBroadcastChannelProfile_Response.schedule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032broadcast channel schedule', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='CSteamTV_GetBroadcastChannelProfile_Response.rules', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027broadcast channel rules', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='panels', full_name='CSteamTV_GetBroadcastChannelProfile_Response.panels', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030/JSON data representing the channel panel layout', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_partnered', full_name='CSteamTV_GetBroadcastChannelProfile_Response.is_partnered', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1841,
)


_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelImage_Request',
  full_name='CSteamTV_SetBroadcastChannelImage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_SetBroadcastChannelImage_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_type', full_name='CSteamTV_SetBroadcastChannelImage_Request.image_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\017EBroadcastImage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_index', full_name='CSteamTV_SetBroadcastChannelImage_Request.image_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030DIndex of the image (for supporting multiple uploads of the same type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_width', full_name='CSteamTV_SetBroadcastChannelImage_Request.image_width', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\017width in pixels', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_height', full_name='CSteamTV_SetBroadcastChannelImage_Request.image_height', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020height in pixels', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CSteamTV_SetBroadcastChannelImage_Request.file_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\010in bytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_extension', full_name='CSteamTV_SetBroadcastChannelImage_Request.file_extension', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\007eg .jpg', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_hash', full_name='CSteamTV_SetBroadcastChannelImage_Request.file_hash', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\timage SHA', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undo', full_name='CSteamTV_SetBroadcastChannelImage_Request.undo', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"indicates this is a delete request', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1844,
  serialized_end=2373,
)


_CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelImage_Response',
  full_name='CSteamTV_SetBroadcastChannelImage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='replace_image_hash', full_name='CSteamTV_SetBroadcastChannelImage_Response.replace_image_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308set if caller should remove previous SHA file from cache', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2376,
  serialized_end=2510,
)


_CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelImages_Request',
  full_name='CSteamTV_GetBroadcastChannelImages_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelImages_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_types', full_name='CSteamTV_GetBroadcastChannelImages_Request.image_types', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\027list of EBroadcastImage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2513,
  serialized_end=2685,
)


_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES = _descriptor.Descriptor(
  name='Images',
  full_name='CSteamTV_GetBroadcastChannelImages_Response.Images',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_type', full_name='CSteamTV_GetBroadcastChannelImages_Response.Images.image_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021Type of the image', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_path', full_name='CSteamTV_GetBroadcastChannelImages_Response.Images.image_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032Path to the uploaded image', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_index', full_name='CSteamTV_GetBroadcastChannelImages_Response.Images.image_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\022Index of the image', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2805,
  serialized_end=3003,
)

_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelImages_Response',
  full_name='CSteamTV_GetBroadcastChannelImages_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='images', full_name='CSteamTV_GetBroadcastChannelImages_Response.images', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2688,
  serialized_end=3003,
)


_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS = _descriptor.Descriptor(
  name='Links',
  full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.Links',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link_index', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.Links.link_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304Index of the link (lower number has higher priority)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.Links.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\004URL ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_description', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.Links.link_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301URL description that will show in the link region', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.Links.left', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Left X position in 100th of a % of the video width', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.Links.top', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Top Y position in 100th of a % of the video height', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.Links.width', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030/Region Width in 100th of a % of the video width', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.Links.height', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301Region Height in 100th of a % of the video height', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3185,
  serialized_end=3652,
)

_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelLinkRegions_Request',
  full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='links', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request.links', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3006,
  serialized_end=3652,
)


_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelLinkRegions_Response',
  full_name='CSteamTV_SetBroadcastChannelLinkRegions_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3654,
  serialized_end=3704,
)


_CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelLinks_Request',
  full_name='CSteamTV_GetBroadcastChannelLinks_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelLinks_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3706,
  serialized_end=3805,
)


_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS = _descriptor.Descriptor(
  name='Links',
  full_name='CSteamTV_GetBroadcastChannelLinks_Response.Links',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link_index', full_name='CSteamTV_GetBroadcastChannelLinks_Response.Links.link_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304Index of the link (lower number has higher priority)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='CSteamTV_GetBroadcastChannelLinks_Response.Links.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\004URL ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_description', full_name='CSteamTV_GetBroadcastChannelLinks_Response.Links.link_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301URL description that will show in the link region', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left', full_name='CSteamTV_GetBroadcastChannelLinks_Response.Links.left', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Left X position in 100th of a % of the video width', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top', full_name='CSteamTV_GetBroadcastChannelLinks_Response.Links.top', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0302Top Y position in 100th of a % of the video height', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='CSteamTV_GetBroadcastChannelLinks_Response.Links.width', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030/Region Width in 100th of a % of the video width', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='CSteamTV_GetBroadcastChannelLinks_Response.Links.height', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301Region Height in 100th of a % of the video height', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3185,
  serialized_end=3652,
)

_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelLinks_Response',
  full_name='CSteamTV_GetBroadcastChannelLinks_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='links', full_name='CSteamTV_GetBroadcastChannelLinks_Response.links', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3808,
  serialized_end=4388,
)


_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelBroadcasters_Request',
  full_name='CSteamTV_GetBroadcastChannelBroadcasters_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4390,
  serialized_end=4496,
)


_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER = _descriptor.Descriptor(
  name='Broadcaster',
  full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcaster Steam ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020Broadcaster name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtmp_token', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster.rtmp_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030Broadcaster upload token', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4639,
  serialized_end=4781,
)

_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelBroadcasters_Response',
  full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasters', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response.broadcasters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4499,
  serialized_end=4781,
)


_CSTEAMTV_GETFOLLOWEDCHANNELS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetFollowedChannels_Request',
  full_name='CSteamTV_GetFollowedChannels_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4783,
  serialized_end=4821,
)


_GETBROADCASTCHANNELENTRY = _descriptor.Descriptor(
  name='GetBroadcastChannelEntry',
  full_name='GetBroadcastChannelEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='GetBroadcastChannelEntry.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031Broadcast channel ID or 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='GetBroadcastChannelEntry.unique_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Unique broadcast channel name for URL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='GetBroadcastChannelEntry.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\033Long broadcast channel name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='GetBroadcastChannelEntry.appid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300The game ID the requested broadcaster is playing', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewers', full_name='GetBroadcastChannelEntry.viewers', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$Number of viewers currently watching', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='views', full_name='GetBroadcastChannelEntry.views', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Number of total views of this channel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_url', full_name='GetBroadcastChannelEntry.thumbnail_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025Current thumbnail URL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='followers', full_name='GetBroadcastChannelEntry.followers', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#Number of followers of this channel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headline', full_name='GetBroadcastChannelEntry.headline', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031short channel description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar_url', full_name='GetBroadcastChannelEntry.avatar_url', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024community avatar url', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='GetBroadcastChannelEntry.broadcaster_steamid', index=10,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035Current broadcaster streaming', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribers', full_name='GetBroadcastChannelEntry.subscribers', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Number of subscribers of this channel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='background_url', full_name='GetBroadcastChannelEntry.background_url', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Background image url', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_featured', full_name='GetBroadcastChannelEntry.is_featured', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037Whether the channel is featured', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_disabled', full_name='GetBroadcastChannelEntry.is_disabled', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\037Whether the channel is disabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_live', full_name='GetBroadcastChannelEntry.is_live', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030 Whether the channel is streaming', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='GetBroadcastChannelEntry.language', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035The language the stream is in', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='GetBroadcastChannelEntry.reports', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%The number of reports the channel has', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_partnered', full_name='GetBroadcastChannelEntry.is_partnered', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4824,
  serialized_end=5897,
)


_CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetFollowedChannels_Response',
  full_name='CSteamTV_GetFollowedChannels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetFollowedChannels_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030The list of broadcasters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5899,
  serialized_end=6012,
)


_CSTEAMTV_GETSUBSCRIBEDCHANNELS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetSubscribedChannels_Request',
  full_name='CSteamTV_GetSubscribedChannels_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6014,
  serialized_end=6054,
)


_CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetSubscribedChannels_Response',
  full_name='CSteamTV_GetSubscribedChannels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetSubscribedChannels_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030The list of broadcasters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6056,
  serialized_end=6171,
)


_CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelStatus_Request',
  full_name='CSteamTV_GetBroadcastChannelStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelStatus_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6173,
  serialized_end=6273,
)


_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelStatus_Response',
  full_name='CSteamTV_GetBroadcastChannelStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_live', full_name='CSteamTV_GetBroadcastChannelStatus_Response.is_live', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*Indicates whether the channel is streaming', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_disabled', full_name='CSteamTV_GetBroadcastChannelStatus_Response.is_disabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030/Indicates whether the channel has been disabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamTV_GetBroadcastChannelStatus_Response.appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0300The game ID the requested broadcaster is playing', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewers', full_name='CSteamTV_GetBroadcastChannelStatus_Response.viewers', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030$Number of viewers currently watching', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='views', full_name='CSteamTV_GetBroadcastChannelStatus_Response.views', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Number of total views of this channel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CSteamTV_GetBroadcastChannelStatus_Response.broadcaster_steamid', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\035Current broadcaster streaming', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_url', full_name='CSteamTV_GetBroadcastChannelStatus_Response.thumbnail_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025Current thumbnail URL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='followers', full_name='CSteamTV_GetBroadcastChannelStatus_Response.followers', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#Number of followers of this channel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribers', full_name='CSteamTV_GetBroadcastChannelStatus_Response.subscribers', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Number of subscribers of this channel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='CSteamTV_GetBroadcastChannelStatus_Response.unique_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_session_id', full_name='CSteamTV_GetBroadcastChannelStatus_Response.broadcast_session_id', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6276,
  serialized_end=6935,
)


_CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_FollowBroadcastChannel_Request',
  full_name='CSteamTV_FollowBroadcastChannel_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_FollowBroadcastChannel_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undo', full_name='CSteamTV_FollowBroadcastChannel_Request.undo', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030%Indicates this is an unfollow request', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6938,
  serialized_end=7092,
)


_CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_FollowBroadcastChannel_Response',
  full_name='CSteamTV_FollowBroadcastChannel_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_followed', full_name='CSteamTV_FollowBroadcastChannel_Response.is_followed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!Whether the user is now following', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7094,
  serialized_end=7196,
)


_CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_SubscribeBroadcastChannel_Request',
  full_name='CSteamTV_SubscribeBroadcastChannel_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_SubscribeBroadcastChannel_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7198,
  serialized_end=7298,
)


_CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SubscribeBroadcastChannel_Response',
  full_name='CSteamTV_SubscribeBroadcastChannel_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_subscribed', full_name='CSteamTV_SubscribeBroadcastChannel_Response.is_subscribed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"Whether the user is now subscribed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7300,
  serialized_end=7408,
)


_CSTEAMTV_GETBROADCASTCHANNELCLIPS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelClips_Request',
  full_name='CSteamTV_GetBroadcastChannelClips_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelClips_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7410,
  serialized_end=7483,
)


_CSTEAMTV_BROADCASTCLIPINFO = _descriptor.Descriptor(
  name='CSteamTV_BroadcastClipInfo',
  full_name='CSteamTV_BroadcastClipInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_clip_id', full_name='CSteamTV_BroadcastClipInfo.broadcast_clip_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021broadcast clip ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CSteamTV_BroadcastClipInfo.channel_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast Channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CSteamTV_BroadcastClipInfo.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\034App ID stream is tagged with', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CSteamTV_BroadcastClipInfo.broadcaster_steamid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Broadcaster SteamID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_steamid', full_name='CSteamTV_BroadcastClipInfo.creator_steamid', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\022Clip-maker SteamID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_description', full_name='CSteamTV_BroadcastClipInfo.video_description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&Short name or description of this clip', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='live_time', full_name='CSteamTV_BroadcastClipInfo.live_time', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"GMT time clip was broadcasted live', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_ms', full_name='CSteamTV_BroadcastClipInfo.length_ms', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025length of video in MS', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_path', full_name='CSteamTV_BroadcastClipInfo.thumbnail_path', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'relative path for thumbnail URL on host', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7486,
  serialized_end=8008,
)


_CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelClips_Response',
  full_name='CSteamTV_GetBroadcastChannelClips_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clips', full_name='CSteamTV_GetBroadcastChannelClips_Response.clips', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thumbnail_host', full_name='CSteamTV_GetBroadcastChannelClips_Response.thumbnail_host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8010,
  serialized_end=8122,
)


_CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_ReportBroadcastChannel_Request',
  full_name='CSteamTV_ReportBroadcastChannel_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_ReportBroadcastChannel_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='CSteamTV_ReportBroadcastChannel_Request.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031The reason for the report', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8125,
  serialized_end=8269,
)


_CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_ReportBroadcastChannel_Response',
  full_name='CSteamTV_ReportBroadcastChannel_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8271,
  serialized_end=8313,
)


_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelInteraction_Request',
  full_name='CSteamTV_GetBroadcastChannelInteraction_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelInteraction_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\024Broadcast channel ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8315,
  serialized_end=8420,
)


_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelInteraction_Response',
  full_name='CSteamTV_GetBroadcastChannelInteraction_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_followed', full_name='CSteamTV_GetBroadcastChannelInteraction_Response.is_followed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*Whether the user has followed this channel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_subscribed', full_name='CSteamTV_GetBroadcastChannelInteraction_Response.is_subscribed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030/Whether the user has subscribed to this channel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8423,
  serialized_end=8618,
)


_CSTEAMTV_GETGAMES_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetGames_Request',
  full_name='CSteamTV_GetGames_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamTV_GetGames_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023The ID for the game', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='CSteamTV_GetGames_Request.algorithm', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0301The algorithm to use when picking games to return', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CSteamTV_GetGames_Request.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'The maximum number of results to return', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8621,
  serialized_end=8873,
)


_CSTEAMTV_GAME = _descriptor.Descriptor(
  name='CSteamTV_Game',
  full_name='CSteamTV_Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamTV_Game.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023The ID for the game', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_Game.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025The name for the game', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='CSteamTV_Game.image', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\026The image for the game', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewers', full_name='CSteamTV_Game.viewers', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#Number of people watching this game', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channels', full_name='CSteamTV_Game.channels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!Live channels streaming this game', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release_date', full_name='CSteamTV_Game.release_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='developer', full_name='CSteamTV_Game.developer', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publisher', full_name='CSteamTV_Game.publisher', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8876,
  serialized_end=9217,
)


_CSTEAMTV_GETGAMES_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetGames_Response',
  full_name='CSteamTV_GetGames_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetGames_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\021The list of games', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9219,
  serialized_end=9303,
)


_CSTEAMTV_GETCHANNELS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetChannels_Request',
  full_name='CSteamTV_GetChannels_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='CSteamTV_GetChannels_Request.algorithm', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304The algorithm to use when picking channels to return', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CSteamTV_GetChannels_Request.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\'The maximum number of results to return', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamTV_GetChannels_Request.appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!Filter results to only this appid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9306,
  serialized_end=9585,
)


_CSTEAMTV_GETCHANNELS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetChannels_Response',
  full_name='CSteamTV_GetChannels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetChannels_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030!The list of featured broadcasters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9587,
  serialized_end=9701,
)


_CSTEAMTV_ADDCHATBAN_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_AddChatBan_Request',
  full_name='CSteamTV_AddChatBan_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_AddChatBan_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chatter_steamid', full_name='CSteamTV_AddChatBan_Request.chatter_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CSteamTV_AddChatBan_Request.duration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permanent', full_name='CSteamTV_AddChatBan_Request.permanent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undo', full_name='CSteamTV_AddChatBan_Request.undo', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9704,
  serialized_end=9839,
)


_CSTEAMTV_ADDCHATBAN_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_AddChatBan_Response',
  full_name='CSteamTV_AddChatBan_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9841,
  serialized_end=9871,
)


_CSTEAMTV_GETCHATBANS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetChatBans_Request',
  full_name='CSteamTV_GetChatBans_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetChatBans_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9873,
  serialized_end=9933,
)


_CSTEAMTV_CHATBAN = _descriptor.Descriptor(
  name='CSteamTV_ChatBan',
  full_name='CSteamTV_ChatBan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer_steamid', full_name='CSteamTV_ChatBan.issuer_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chatter_steamid', full_name='CSteamTV_ChatBan.chatter_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_expires', full_name='CSteamTV_ChatBan.time_expires', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permanent', full_name='CSteamTV_ChatBan.permanent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_ChatBan.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9935,
  serialized_end=10057,
)


_CSTEAMTV_GETCHATBANS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetChatBans_Response',
  full_name='CSteamTV_GetChatBans_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetChatBans_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\020The list of bans', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10059,
  serialized_end=10148,
)


_CSTEAMTV_ADDCHATMODERATOR_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_AddChatModerator_Request',
  full_name='CSteamTV_AddChatModerator_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_AddChatModerator_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moderator_steamid', full_name='CSteamTV_AddChatModerator_Request.moderator_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undo', full_name='CSteamTV_AddChatModerator_Request.undo', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10150,
  serialized_end=10256,
)


_CSTEAMTV_ADDCHATMODERATOR_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_AddChatModerator_Response',
  full_name='CSteamTV_AddChatModerator_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10258,
  serialized_end=10294,
)


_CSTEAMTV_GETCHATMODERATORS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetChatModerators_Request',
  full_name='CSteamTV_GetChatModerators_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetChatModerators_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10296,
  serialized_end=10362,
)


_CSTEAMTV_CHATMODERATOR = _descriptor.Descriptor(
  name='CSteamTV_ChatModerator',
  full_name='CSteamTV_ChatModerator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSteamTV_ChatModerator.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_ChatModerator.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10364,
  serialized_end=10419,
)


_CSTEAMTV_GETCHATMODERATORS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetChatModerators_Response',
  full_name='CSteamTV_GetChatModerators_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetChatModerators_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\026The list of moderators', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10421,
  serialized_end=10528,
)


_CSTEAMTV_ADDWORDBAN_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_AddWordBan_Request',
  full_name='CSteamTV_AddWordBan_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_AddWordBan_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='word', full_name='CSteamTV_AddWordBan_Request.word', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undo', full_name='CSteamTV_AddWordBan_Request.undo', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10530,
  serialized_end=10617,
)


_CSTEAMTV_ADDWORDBAN_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_AddWordBan_Response',
  full_name='CSteamTV_AddWordBan_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10619,
  serialized_end=10649,
)


_CSTEAMTV_GETWORDBANS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetWordBans_Request',
  full_name='CSteamTV_GetWordBans_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetWordBans_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10651,
  serialized_end=10711,
)


_CSTEAMTV_GETWORDBANS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetWordBans_Response',
  full_name='CSteamTV_GetWordBans_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetWordBans_Response.results', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030The list of banned words', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10713,
  serialized_end=10791,
)


_CSTEAMTV_JOINCHAT_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_JoinChat_Request',
  full_name='CSteamTV_JoinChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_JoinChat_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10793,
  serialized_end=10850,
)


_CSTEAMTV_JOINCHAT_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_JoinChat_Response',
  full_name='CSteamTV_JoinChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CSteamTV_JoinChat_Response.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_url_template', full_name='CSteamTV_JoinChat_Response.view_url_template', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flair_group_ids', full_name='CSteamTV_JoinChat_Response.flair_group_ids', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10852,
  serialized_end=10949,
)


_CSTEAMTV_SEARCH_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_Search_Request',
  full_name='CSteamTV_Search_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='term', full_name='CSteamTV_Search_Request.term', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10951,
  serialized_end=10990,
)


_CSTEAMTV_SEARCH_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_Search_Response',
  full_name='CSteamTV_Search_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_Search_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030The list of broadcasters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10992,
  serialized_end=11092,
)


_CSTEAMTV_GETSTEAMTVUSERSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetSteamTVUserSettings_Request',
  full_name='CSteamTV_GetSteamTVUserSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11094,
  serialized_end=11135,
)


_CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetSteamTVUserSettings_Response',
  full_name='CSteamTV_GetSteamTVUserSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_live_email', full_name='CSteamTV_GetSteamTVUserSettings_Response.stream_live_email', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&Send email when followed stream starts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_live_notification', full_name='CSteamTV_GetSteamTVUserSettings_Response.stream_live_notification', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303Send Steam notification when followed stream starts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11138,
  serialized_end=11342,
)


_CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_SetSteamTVUserSettings_Request',
  full_name='CSteamTV_SetSteamTVUserSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_live_email', full_name='CSteamTV_SetSteamTVUserSettings_Request.stream_live_email', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&Send email when followed stream starts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_live_notification', full_name='CSteamTV_SetSteamTVUserSettings_Request.stream_live_notification', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303Send Steam notification when followed stream starts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11345,
  serialized_end=11548,
)


_CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SetSteamTVUserSettings_Response',
  full_name='CSteamTV_SetSteamTVUserSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11550,
  serialized_end=11592,
)


_CSTEAMTV_GETMYBROADCASTCHANNELS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetMyBroadcastChannels_Request',
  full_name='CSteamTV_GetMyBroadcastChannels_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11594,
  serialized_end=11635,
)


_CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetMyBroadcastChannels_Response',
  full_name='CSteamTV_GetMyBroadcastChannels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetMyBroadcastChannels_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\030The list of broadcasters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11637,
  serialized_end=11753,
)


_CSTEAMTV_GETHOMEPAGECONTENTS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetHomePageContents_Request',
  full_name='CSteamTV_GetHomePageContents_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11755,
  serialized_end=11793,
)


_CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_Takeover',
  full_name='CSteamTV_HomePageTemplate_Takeover',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='CSteamTV_HomePageTemplate_Takeover.broadcasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11795,
  serialized_end=11878,
)


_CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_SingleGame',
  full_name='CSteamTV_HomePageTemplate_SingleGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='CSteamTV_HomePageTemplate_SingleGame.broadcasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamTV_HomePageTemplate_SingleGame.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_SingleGame.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11880,
  serialized_end=11995,
)


_GAMELISTENTRY = _descriptor.Descriptor(
  name='GameListEntry',
  full_name='GameListEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='GameListEntry.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='GameListEntry.game_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='GameListEntry.broadcast', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11997,
  serialized_end=12092,
)


_CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_GameList',
  full_name='CSteamTV_HomePageTemplate_GameList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='CSteamTV_HomePageTemplate_GameList.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_GameList.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12094,
  serialized_end=12178,
)


_CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_QuickExplore',
  full_name='CSteamTV_HomePageTemplate_QuickExplore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='CSteamTV_HomePageTemplate_QuickExplore.broadcasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_QuickExplore.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12180,
  serialized_end=12282,
)


_CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_ConveyorBelt',
  full_name='CSteamTV_HomePageTemplate_ConveyorBelt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='CSteamTV_HomePageTemplate_ConveyorBelt.broadcasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_ConveyorBelt.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12284,
  serialized_end=12386,
)


_CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_WatchParty',
  full_name='CSteamTV_HomePageTemplate_WatchParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='CSteamTV_HomePageTemplate_WatchParty.broadcast', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_WatchParty.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CSteamTV_HomePageTemplate_WatchParty.chat_group_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12388,
  serialized_end=12510,
)


_CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_Developer',
  full_name='CSteamTV_HomePageTemplate_Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='CSteamTV_HomePageTemplate_Developer.broadcast', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_Developer.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12512,
  serialized_end=12610,
)


_CSTEAMTV_HOMEPAGETEMPLATE_EVENT = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_Event',
  full_name='CSteamTV_HomePageTemplate_Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_Event.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12612,
  serialized_end=12660,
)


_CSTEAMTV_HOMEPAGECONTENTROW = _descriptor.Descriptor(
  name='CSteamTV_HomePageContentRow',
  full_name='CSteamTV_HomePageContentRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_type', full_name='CSteamTV_HomePageContentRow.template_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='takeover', full_name='CSteamTV_HomePageContentRow.takeover', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single_game', full_name='CSteamTV_HomePageContentRow.single_game', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='game_list', full_name='CSteamTV_HomePageContentRow.game_list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quick_explore', full_name='CSteamTV_HomePageContentRow.quick_explore', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conveyor_belt', full_name='CSteamTV_HomePageContentRow.conveyor_belt', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watch_party', full_name='CSteamTV_HomePageContentRow.watch_party', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='developer', full_name='CSteamTV_HomePageContentRow.developer', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event', full_name='CSteamTV_HomePageContentRow.event', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12663,
  serialized_end=13241,
)


_CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetHomePageContents_Response',
  full_name='CSteamTV_GetHomePageContents_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows', full_name='CSteamTV_GetHomePageContents_Response.rows', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13243,
  serialized_end=13326,
)


_CSTEAMTV_APPCHEER_SINGLECHEERTYPE = _descriptor.Descriptor(
  name='CSteamTV_AppCheer_SingleCheerType',
  full_name='CSteamTV_AppCheer_SingleCheerType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cheer_type', full_name='CSteamTV_AppCheer_SingleCheerType.cheer_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030HThe type of cheer. App dependent (different teams, heroes, players, etc)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cheer_amount', full_name='CSteamTV_AppCheer_SingleCheerType.cheer_amount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\025The amount of cheers.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13329,
  serialized_end=13511,
)


_CSTEAMTV_APPCHEER_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_AppCheer_Request',
  full_name='CSteamTV_AppCheer_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CSteamTV_AppCheer_Request.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031App ID this cheer is for.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cheer_target_id', full_name='CSteamTV_AppCheer_Request.cheer_target_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030hThe thing being cheered on. ID is app dependent (could be steam id, match id, lobby id, server id, etc).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cheers', full_name='CSteamTV_AppCheer_Request.cheers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030QThe set of cheers this request represents (could be multiple of different types).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13514,
  serialized_end=13864,
)


_CSTEAMTV_APPCHEER_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_AppCheer_Response',
  full_name='CSteamTV_AppCheer_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aggregation_delay_ms', full_name='CSteamTV_AppCheer_Response.aggregation_delay_ms', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\254\001The amount of time in milliseconds that the client should aggregate cheers before sending them. The server can control this dynamically to ask clients to slow down sending.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13867,
  serialized_end=14106,
)

_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['image_type'].enum_type = _EBROADCASTIMAGETYPE
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST.fields_by_name['image_types'].enum_type = _EBROADCASTIMAGETYPE
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES.fields_by_name['image_type'].enum_type = _EBROADCASTIMAGETYPE
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES.containing_type = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE.fields_by_name['images'].message_type = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS.containing_type = _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST.fields_by_name['links'].message_type = _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS.containing_type = _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE.fields_by_name['links'].message_type = _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS
_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER.containing_type = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE
_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE.fields_by_name['broadcasters'].message_type = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER
_CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE.fields_by_name['clips'].message_type = _CSTEAMTV_BROADCASTCLIPINFO
_CSTEAMTV_GETGAMES_REQUEST.fields_by_name['algorithm'].enum_type = _EGETGAMESALGORITHM
_CSTEAMTV_GAME.fields_by_name['channels'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETGAMES_RESPONSE.fields_by_name['results'].message_type = _CSTEAMTV_GAME
_CSTEAMTV_GETCHANNELS_REQUEST.fields_by_name['algorithm'].enum_type = _EGETCHANNELSALGORITHM
_CSTEAMTV_GETCHANNELS_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETCHATBANS_RESPONSE.fields_by_name['results'].message_type = _CSTEAMTV_CHATBAN
_CSTEAMTV_GETCHATMODERATORS_RESPONSE.fields_by_name['results'].message_type = _CSTEAMTV_CHATMODERATOR
_CSTEAMTV_SEARCH_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER.fields_by_name['broadcasts'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME.fields_by_name['broadcasts'].message_type = _GETBROADCASTCHANNELENTRY
_GAMELISTENTRY.fields_by_name['broadcast'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST.fields_by_name['entries'].message_type = _GAMELISTENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE.fields_by_name['broadcasts'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT.fields_by_name['broadcasts'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY.fields_by_name['broadcast'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER.fields_by_name['broadcast'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['template_type'].enum_type = _ESTEAMTVCONTENTTEMPLATE
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['takeover'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['single_game'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['game_list'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['quick_explore'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['conveyor_belt'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['watch_party'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['developer'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['event'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_EVENT
_CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE.fields_by_name['rows'].message_type = _CSTEAMTV_HOMEPAGECONTENTROW
_CSTEAMTV_APPCHEER_REQUEST.fields_by_name['cheers'].message_type = _CSTEAMTV_APPCHEER_SINGLECHEERTYPE
DESCRIPTOR.message_types_by_name['CSteamTV_CreateBroadcastChannel_Request'] = _CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_CreateBroadcastChannel_Response'] = _CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelID_Request'] = _CSTEAMTV_GETBROADCASTCHANNELID_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelID_Response'] = _CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelProfile_Request'] = _CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelProfile_Response'] = _CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelProfile_Request'] = _CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelProfile_Response'] = _CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelImage_Request'] = _CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelImage_Response'] = _CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelImages_Request'] = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelImages_Response'] = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelLinkRegions_Request'] = _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelLinkRegions_Response'] = _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelLinks_Request'] = _CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelLinks_Response'] = _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelBroadcasters_Request'] = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelBroadcasters_Response'] = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetFollowedChannels_Request'] = _CSTEAMTV_GETFOLLOWEDCHANNELS_REQUEST
DESCRIPTOR.message_types_by_name['GetBroadcastChannelEntry'] = _GETBROADCASTCHANNELENTRY
DESCRIPTOR.message_types_by_name['CSteamTV_GetFollowedChannels_Response'] = _CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetSubscribedChannels_Request'] = _CSTEAMTV_GETSUBSCRIBEDCHANNELS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetSubscribedChannels_Response'] = _CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelStatus_Request'] = _CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelStatus_Response'] = _CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_FollowBroadcastChannel_Request'] = _CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_FollowBroadcastChannel_Response'] = _CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SubscribeBroadcastChannel_Request'] = _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_SubscribeBroadcastChannel_Response'] = _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelClips_Request'] = _CSTEAMTV_GETBROADCASTCHANNELCLIPS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_BroadcastClipInfo'] = _CSTEAMTV_BROADCASTCLIPINFO
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelClips_Response'] = _CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_ReportBroadcastChannel_Request'] = _CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_ReportBroadcastChannel_Response'] = _CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelInteraction_Request'] = _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelInteraction_Response'] = _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetGames_Request'] = _CSTEAMTV_GETGAMES_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_Game'] = _CSTEAMTV_GAME
DESCRIPTOR.message_types_by_name['CSteamTV_GetGames_Response'] = _CSTEAMTV_GETGAMES_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetChannels_Request'] = _CSTEAMTV_GETCHANNELS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetChannels_Response'] = _CSTEAMTV_GETCHANNELS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_AddChatBan_Request'] = _CSTEAMTV_ADDCHATBAN_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_AddChatBan_Response'] = _CSTEAMTV_ADDCHATBAN_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetChatBans_Request'] = _CSTEAMTV_GETCHATBANS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_ChatBan'] = _CSTEAMTV_CHATBAN
DESCRIPTOR.message_types_by_name['CSteamTV_GetChatBans_Response'] = _CSTEAMTV_GETCHATBANS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_AddChatModerator_Request'] = _CSTEAMTV_ADDCHATMODERATOR_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_AddChatModerator_Response'] = _CSTEAMTV_ADDCHATMODERATOR_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetChatModerators_Request'] = _CSTEAMTV_GETCHATMODERATORS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_ChatModerator'] = _CSTEAMTV_CHATMODERATOR
DESCRIPTOR.message_types_by_name['CSteamTV_GetChatModerators_Response'] = _CSTEAMTV_GETCHATMODERATORS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_AddWordBan_Request'] = _CSTEAMTV_ADDWORDBAN_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_AddWordBan_Response'] = _CSTEAMTV_ADDWORDBAN_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetWordBans_Request'] = _CSTEAMTV_GETWORDBANS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetWordBans_Response'] = _CSTEAMTV_GETWORDBANS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_JoinChat_Request'] = _CSTEAMTV_JOINCHAT_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_JoinChat_Response'] = _CSTEAMTV_JOINCHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_Search_Request'] = _CSTEAMTV_SEARCH_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_Search_Response'] = _CSTEAMTV_SEARCH_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetSteamTVUserSettings_Request'] = _CSTEAMTV_GETSTEAMTVUSERSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetSteamTVUserSettings_Response'] = _CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SetSteamTVUserSettings_Request'] = _CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_SetSteamTVUserSettings_Response'] = _CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetMyBroadcastChannels_Request'] = _CSTEAMTV_GETMYBROADCASTCHANNELS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_GetMyBroadcastChannels_Response'] = _CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetHomePageContents_Request'] = _CSTEAMTV_GETHOMEPAGECONTENTS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_Takeover'] = _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_SingleGame'] = _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME
DESCRIPTOR.message_types_by_name['GameListEntry'] = _GAMELISTENTRY
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_GameList'] = _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_QuickExplore'] = _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_ConveyorBelt'] = _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_WatchParty'] = _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_Developer'] = _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_Event'] = _CSTEAMTV_HOMEPAGETEMPLATE_EVENT
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageContentRow'] = _CSTEAMTV_HOMEPAGECONTENTROW
DESCRIPTOR.message_types_by_name['CSteamTV_GetHomePageContents_Response'] = _CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_AppCheer_SingleCheerType'] = _CSTEAMTV_APPCHEER_SINGLECHEERTYPE
DESCRIPTOR.message_types_by_name['CSteamTV_AppCheer_Request'] = _CSTEAMTV_APPCHEER_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_AppCheer_Response'] = _CSTEAMTV_APPCHEER_RESPONSE
DESCRIPTOR.enum_types_by_name['EBroadcastImageType'] = _EBROADCASTIMAGETYPE
DESCRIPTOR.enum_types_by_name['EGetGamesAlgorithm'] = _EGETGAMESALGORITHM
DESCRIPTOR.enum_types_by_name['EGetChannelsAlgorithm'] = _EGETCHANNELSALGORITHM
DESCRIPTOR.enum_types_by_name['ESteamTVContentTemplate'] = _ESTEAMTVCONTENTTEMPLATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CSteamTV_CreateBroadcastChannel_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_CreateBroadcastChannel_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_CreateBroadcastChannel_Request)
  })
_sym_db.RegisterMessage(CSteamTV_CreateBroadcastChannel_Request)

CSteamTV_CreateBroadcastChannel_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_CreateBroadcastChannel_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_CreateBroadcastChannel_Response)
  })
_sym_db.RegisterMessage(CSteamTV_CreateBroadcastChannel_Response)

CSteamTV_GetBroadcastChannelID_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelID_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELID_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelID_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelID_Request)

CSteamTV_GetBroadcastChannelID_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelID_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelID_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelID_Response)

CSteamTV_SetBroadcastChannelProfile_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelProfile_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelProfile_Request)
  })
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelProfile_Request)

CSteamTV_SetBroadcastChannelProfile_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelProfile_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelProfile_Response)
  })
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelProfile_Response)

CSteamTV_GetBroadcastChannelProfile_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelProfile_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelProfile_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelProfile_Request)

CSteamTV_GetBroadcastChannelProfile_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelProfile_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelProfile_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelProfile_Response)

CSteamTV_SetBroadcastChannelImage_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelImage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelImage_Request)
  })
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelImage_Request)

CSteamTV_SetBroadcastChannelImage_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelImage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelImage_Response)
  })
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelImage_Response)

CSteamTV_GetBroadcastChannelImages_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelImages_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelImages_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelImages_Request)

CSteamTV_GetBroadcastChannelImages_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelImages_Response', (_message.Message,), {

  'Images' : _reflection.GeneratedProtocolMessageType('Images', (_message.Message,), {
    'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES,
    '__module__' : 'steammessages_steamtv_pb2'
    # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelImages_Response.Images)
    })
  ,
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelImages_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelImages_Response)
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelImages_Response.Images)

CSteamTV_SetBroadcastChannelLinkRegions_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelLinkRegions_Request', (_message.Message,), {

  'Links' : _reflection.GeneratedProtocolMessageType('Links', (_message.Message,), {
    'DESCRIPTOR' : _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS,
    '__module__' : 'steammessages_steamtv_pb2'
    # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelLinkRegions_Request.Links)
    })
  ,
  'DESCRIPTOR' : _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelLinkRegions_Request)
  })
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelLinkRegions_Request)
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelLinkRegions_Request.Links)

CSteamTV_SetBroadcastChannelLinkRegions_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelLinkRegions_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelLinkRegions_Response)
  })
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelLinkRegions_Response)

CSteamTV_GetBroadcastChannelLinks_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelLinks_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelLinks_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelLinks_Request)

CSteamTV_GetBroadcastChannelLinks_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelLinks_Response', (_message.Message,), {

  'Links' : _reflection.GeneratedProtocolMessageType('Links', (_message.Message,), {
    'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS,
    '__module__' : 'steammessages_steamtv_pb2'
    # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelLinks_Response.Links)
    })
  ,
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelLinks_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelLinks_Response)
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelLinks_Response.Links)

CSteamTV_GetBroadcastChannelBroadcasters_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelBroadcasters_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelBroadcasters_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelBroadcasters_Request)

CSteamTV_GetBroadcastChannelBroadcasters_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelBroadcasters_Response', (_message.Message,), {

  'Broadcaster' : _reflection.GeneratedProtocolMessageType('Broadcaster', (_message.Message,), {
    'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER,
    '__module__' : 'steammessages_steamtv_pb2'
    # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster)
    })
  ,
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelBroadcasters_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelBroadcasters_Response)
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelBroadcasters_Response.Broadcaster)

CSteamTV_GetFollowedChannels_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetFollowedChannels_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETFOLLOWEDCHANNELS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetFollowedChannels_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetFollowedChannels_Request)

GetBroadcastChannelEntry = _reflection.GeneratedProtocolMessageType('GetBroadcastChannelEntry', (_message.Message,), {
  'DESCRIPTOR' : _GETBROADCASTCHANNELENTRY,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:GetBroadcastChannelEntry)
  })
_sym_db.RegisterMessage(GetBroadcastChannelEntry)

CSteamTV_GetFollowedChannels_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetFollowedChannels_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetFollowedChannels_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetFollowedChannels_Response)

CSteamTV_GetSubscribedChannels_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetSubscribedChannels_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETSUBSCRIBEDCHANNELS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetSubscribedChannels_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetSubscribedChannels_Request)

CSteamTV_GetSubscribedChannels_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetSubscribedChannels_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetSubscribedChannels_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetSubscribedChannels_Response)

CSteamTV_GetBroadcastChannelStatus_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelStatus_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelStatus_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelStatus_Request)

CSteamTV_GetBroadcastChannelStatus_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelStatus_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelStatus_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelStatus_Response)

CSteamTV_FollowBroadcastChannel_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_FollowBroadcastChannel_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_FollowBroadcastChannel_Request)
  })
_sym_db.RegisterMessage(CSteamTV_FollowBroadcastChannel_Request)

CSteamTV_FollowBroadcastChannel_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_FollowBroadcastChannel_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_FollowBroadcastChannel_Response)
  })
_sym_db.RegisterMessage(CSteamTV_FollowBroadcastChannel_Response)

CSteamTV_SubscribeBroadcastChannel_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_SubscribeBroadcastChannel_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SubscribeBroadcastChannel_Request)
  })
_sym_db.RegisterMessage(CSteamTV_SubscribeBroadcastChannel_Request)

CSteamTV_SubscribeBroadcastChannel_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SubscribeBroadcastChannel_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SubscribeBroadcastChannel_Response)
  })
_sym_db.RegisterMessage(CSteamTV_SubscribeBroadcastChannel_Response)

CSteamTV_GetBroadcastChannelClips_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelClips_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELCLIPS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelClips_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelClips_Request)

CSteamTV_BroadcastClipInfo = _reflection.GeneratedProtocolMessageType('CSteamTV_BroadcastClipInfo', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_BROADCASTCLIPINFO,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_BroadcastClipInfo)
  })
_sym_db.RegisterMessage(CSteamTV_BroadcastClipInfo)

CSteamTV_GetBroadcastChannelClips_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelClips_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelClips_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelClips_Response)

CSteamTV_ReportBroadcastChannel_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_ReportBroadcastChannel_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_ReportBroadcastChannel_Request)
  })
_sym_db.RegisterMessage(CSteamTV_ReportBroadcastChannel_Request)

CSteamTV_ReportBroadcastChannel_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_ReportBroadcastChannel_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_ReportBroadcastChannel_Response)
  })
_sym_db.RegisterMessage(CSteamTV_ReportBroadcastChannel_Response)

CSteamTV_GetBroadcastChannelInteraction_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelInteraction_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelInteraction_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelInteraction_Request)

CSteamTV_GetBroadcastChannelInteraction_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelInteraction_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelInteraction_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelInteraction_Response)

CSteamTV_GetGames_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetGames_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETGAMES_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetGames_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetGames_Request)

CSteamTV_Game = _reflection.GeneratedProtocolMessageType('CSteamTV_Game', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GAME,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_Game)
  })
_sym_db.RegisterMessage(CSteamTV_Game)

CSteamTV_GetGames_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetGames_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETGAMES_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetGames_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetGames_Response)

CSteamTV_GetChannels_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChannels_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETCHANNELS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChannels_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetChannels_Request)

CSteamTV_GetChannels_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChannels_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETCHANNELS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChannels_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetChannels_Response)

CSteamTV_AddChatBan_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_AddChatBan_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_ADDCHATBAN_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddChatBan_Request)
  })
_sym_db.RegisterMessage(CSteamTV_AddChatBan_Request)

CSteamTV_AddChatBan_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_AddChatBan_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_ADDCHATBAN_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddChatBan_Response)
  })
_sym_db.RegisterMessage(CSteamTV_AddChatBan_Response)

CSteamTV_GetChatBans_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChatBans_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETCHATBANS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChatBans_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetChatBans_Request)

CSteamTV_ChatBan = _reflection.GeneratedProtocolMessageType('CSteamTV_ChatBan', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_CHATBAN,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_ChatBan)
  })
_sym_db.RegisterMessage(CSteamTV_ChatBan)

CSteamTV_GetChatBans_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChatBans_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETCHATBANS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChatBans_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetChatBans_Response)

CSteamTV_AddChatModerator_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_AddChatModerator_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_ADDCHATMODERATOR_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddChatModerator_Request)
  })
_sym_db.RegisterMessage(CSteamTV_AddChatModerator_Request)

CSteamTV_AddChatModerator_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_AddChatModerator_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_ADDCHATMODERATOR_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddChatModerator_Response)
  })
_sym_db.RegisterMessage(CSteamTV_AddChatModerator_Response)

CSteamTV_GetChatModerators_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChatModerators_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETCHATMODERATORS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChatModerators_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetChatModerators_Request)

CSteamTV_ChatModerator = _reflection.GeneratedProtocolMessageType('CSteamTV_ChatModerator', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_CHATMODERATOR,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_ChatModerator)
  })
_sym_db.RegisterMessage(CSteamTV_ChatModerator)

CSteamTV_GetChatModerators_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChatModerators_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETCHATMODERATORS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChatModerators_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetChatModerators_Response)

CSteamTV_AddWordBan_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_AddWordBan_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_ADDWORDBAN_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddWordBan_Request)
  })
_sym_db.RegisterMessage(CSteamTV_AddWordBan_Request)

CSteamTV_AddWordBan_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_AddWordBan_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_ADDWORDBAN_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddWordBan_Response)
  })
_sym_db.RegisterMessage(CSteamTV_AddWordBan_Response)

CSteamTV_GetWordBans_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetWordBans_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETWORDBANS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetWordBans_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetWordBans_Request)

CSteamTV_GetWordBans_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetWordBans_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETWORDBANS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetWordBans_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetWordBans_Response)

CSteamTV_JoinChat_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_JoinChat_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_JOINCHAT_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_JoinChat_Request)
  })
_sym_db.RegisterMessage(CSteamTV_JoinChat_Request)

CSteamTV_JoinChat_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_JoinChat_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_JOINCHAT_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_JoinChat_Response)
  })
_sym_db.RegisterMessage(CSteamTV_JoinChat_Response)

CSteamTV_Search_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_Search_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SEARCH_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_Search_Request)
  })
_sym_db.RegisterMessage(CSteamTV_Search_Request)

CSteamTV_Search_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_Search_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SEARCH_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_Search_Response)
  })
_sym_db.RegisterMessage(CSteamTV_Search_Response)

CSteamTV_GetSteamTVUserSettings_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetSteamTVUserSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETSTEAMTVUSERSETTINGS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetSteamTVUserSettings_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetSteamTVUserSettings_Request)

CSteamTV_GetSteamTVUserSettings_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetSteamTVUserSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetSteamTVUserSettings_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetSteamTVUserSettings_Response)

CSteamTV_SetSteamTVUserSettings_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_SetSteamTVUserSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetSteamTVUserSettings_Request)
  })
_sym_db.RegisterMessage(CSteamTV_SetSteamTVUserSettings_Request)

CSteamTV_SetSteamTVUserSettings_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SetSteamTVUserSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetSteamTVUserSettings_Response)
  })
_sym_db.RegisterMessage(CSteamTV_SetSteamTVUserSettings_Response)

CSteamTV_GetMyBroadcastChannels_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetMyBroadcastChannels_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETMYBROADCASTCHANNELS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetMyBroadcastChannels_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetMyBroadcastChannels_Request)

CSteamTV_GetMyBroadcastChannels_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetMyBroadcastChannels_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetMyBroadcastChannels_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetMyBroadcastChannels_Response)

CSteamTV_GetHomePageContents_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetHomePageContents_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETHOMEPAGECONTENTS_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetHomePageContents_Request)
  })
_sym_db.RegisterMessage(CSteamTV_GetHomePageContents_Request)

CSteamTV_HomePageTemplate_Takeover = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_Takeover', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_Takeover)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_Takeover)

CSteamTV_HomePageTemplate_SingleGame = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_SingleGame', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_SingleGame)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_SingleGame)

GameListEntry = _reflection.GeneratedProtocolMessageType('GameListEntry', (_message.Message,), {
  'DESCRIPTOR' : _GAMELISTENTRY,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:GameListEntry)
  })
_sym_db.RegisterMessage(GameListEntry)

CSteamTV_HomePageTemplate_GameList = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_GameList', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_GameList)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_GameList)

CSteamTV_HomePageTemplate_QuickExplore = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_QuickExplore', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_QuickExplore)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_QuickExplore)

CSteamTV_HomePageTemplate_ConveyorBelt = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_ConveyorBelt', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_ConveyorBelt)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_ConveyorBelt)

CSteamTV_HomePageTemplate_WatchParty = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_WatchParty', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_WatchParty)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_WatchParty)

CSteamTV_HomePageTemplate_Developer = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_Developer', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_Developer)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_Developer)

CSteamTV_HomePageTemplate_Event = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_Event', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGETEMPLATE_EVENT,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_Event)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_Event)

CSteamTV_HomePageContentRow = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageContentRow', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_HOMEPAGECONTENTROW,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageContentRow)
  })
_sym_db.RegisterMessage(CSteamTV_HomePageContentRow)

CSteamTV_GetHomePageContents_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetHomePageContents_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetHomePageContents_Response)
  })
_sym_db.RegisterMessage(CSteamTV_GetHomePageContents_Response)

CSteamTV_AppCheer_SingleCheerType = _reflection.GeneratedProtocolMessageType('CSteamTV_AppCheer_SingleCheerType', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_APPCHEER_SINGLECHEERTYPE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AppCheer_SingleCheerType)
  })
_sym_db.RegisterMessage(CSteamTV_AppCheer_SingleCheerType)

CSteamTV_AppCheer_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_AppCheer_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_APPCHEER_REQUEST,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AppCheer_Request)
  })
_sym_db.RegisterMessage(CSteamTV_AppCheer_Request)

CSteamTV_AppCheer_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_AppCheer_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSTEAMTV_APPCHEER_RESPONSE,
  '__module__' : 'steammessages_steamtv_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AppCheer_Response)
  })
_sym_db.RegisterMessage(CSteamTV_AppCheer_Response)


DESCRIPTOR._options = None
_CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST.fields_by_name['unique_name']._options = None
_CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELID_REQUEST.fields_by_name['unique_name']._options = None
_CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE.fields_by_name['unique_name']._options = None
_CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE.fields_by_name['steamid']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['name']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['language']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['headline']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['summary']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['avatar_hash']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['schedule']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['rules']._options = None
_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['panels']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['unique_name']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['owner_steamid']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['name']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['language']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['headline']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['summary']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['schedule']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['rules']._options = None
_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE.fields_by_name['panels']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['image_type']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['image_index']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['image_width']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['image_height']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['file_size']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['file_extension']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['file_hash']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST.fields_by_name['undo']._options = None
_CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE.fields_by_name['replace_image_hash']._options = None
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST.fields_by_name['image_types']._options = None
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES.fields_by_name['image_type']._options = None
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES.fields_by_name['image_path']._options = None
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES.fields_by_name['image_index']._options = None
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS.fields_by_name['link_index']._options = None
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS.fields_by_name['url']._options = None
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS.fields_by_name['link_description']._options = None
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS.fields_by_name['left']._options = None
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS.fields_by_name['top']._options = None
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS.fields_by_name['width']._options = None
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS.fields_by_name['height']._options = None
_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS.fields_by_name['link_index']._options = None
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS.fields_by_name['url']._options = None
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS.fields_by_name['link_description']._options = None
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS.fields_by_name['left']._options = None
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS.fields_by_name['top']._options = None
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS.fields_by_name['width']._options = None
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS.fields_by_name['height']._options = None
_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER.fields_by_name['steamid']._options = None
_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER.fields_by_name['name']._options = None
_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER.fields_by_name['rtmp_token']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['broadcast_channel_id']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['unique_name']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['name']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['appid']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['viewers']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['views']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['thumbnail_url']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['followers']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['headline']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['avatar_url']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['broadcaster_steamid']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['subscribers']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['background_url']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['is_featured']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['is_disabled']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['is_live']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['language']._options = None
_GETBROADCASTCHANNELENTRY.fields_by_name['reports']._options = None
_CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['is_live']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['is_disabled']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['appid']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['viewers']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['views']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['broadcaster_steamid']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['thumbnail_url']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['followers']._options = None
_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE.fields_by_name['subscribers']._options = None
_CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST.fields_by_name['undo']._options = None
_CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE.fields_by_name['is_followed']._options = None
_CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE.fields_by_name['is_subscribed']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['broadcast_clip_id']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['channel_id']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['app_id']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['broadcaster_steamid']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['creator_steamid']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['video_description']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['live_time']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['length_ms']._options = None
_CSTEAMTV_BROADCASTCLIPINFO.fields_by_name['thumbnail_path']._options = None
_CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST.fields_by_name['reason']._options = None
_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST.fields_by_name['broadcast_channel_id']._options = None
_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE.fields_by_name['is_followed']._options = None
_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE.fields_by_name['is_subscribed']._options = None
_CSTEAMTV_GETGAMES_REQUEST.fields_by_name['appid']._options = None
_CSTEAMTV_GETGAMES_REQUEST.fields_by_name['algorithm']._options = None
_CSTEAMTV_GETGAMES_REQUEST.fields_by_name['count']._options = None
_CSTEAMTV_GAME.fields_by_name['appid']._options = None
_CSTEAMTV_GAME.fields_by_name['name']._options = None
_CSTEAMTV_GAME.fields_by_name['image']._options = None
_CSTEAMTV_GAME.fields_by_name['viewers']._options = None
_CSTEAMTV_GAME.fields_by_name['channels']._options = None
_CSTEAMTV_GETGAMES_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_GETCHANNELS_REQUEST.fields_by_name['algorithm']._options = None
_CSTEAMTV_GETCHANNELS_REQUEST.fields_by_name['count']._options = None
_CSTEAMTV_GETCHANNELS_REQUEST.fields_by_name['appid']._options = None
_CSTEAMTV_GETCHANNELS_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_GETCHATBANS_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_GETCHATMODERATORS_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_GETWORDBANS_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_SEARCH_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE.fields_by_name['stream_live_email']._options = None
_CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE.fields_by_name['stream_live_notification']._options = None
_CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST.fields_by_name['stream_live_email']._options = None
_CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST.fields_by_name['stream_live_notification']._options = None
_CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE.fields_by_name['results']._options = None
_CSTEAMTV_APPCHEER_SINGLECHEERTYPE.fields_by_name['cheer_type']._options = None
_CSTEAMTV_APPCHEER_SINGLECHEERTYPE.fields_by_name['cheer_amount']._options = None
_CSTEAMTV_APPCHEER_REQUEST.fields_by_name['app_id']._options = None
_CSTEAMTV_APPCHEER_REQUEST.fields_by_name['cheer_target_id']._options = None
_CSTEAMTV_APPCHEER_REQUEST.fields_by_name['cheers']._options = None
_CSTEAMTV_APPCHEER_RESPONSE.fields_by_name['aggregation_delay_ms']._options = None

_STEAMTV = _descriptor.ServiceDescriptor(
  name='SteamTV',
  full_name='SteamTV',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\037Methods for Steam TV operations',
  create_key=_descriptor._internal_create_key,
  serialized_start=15122,
  serialized_end=20049,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateBroadcastChannel',
    full_name='SteamTV.CreateBroadcastChannel',
    index=0,
    containing_service=None,
    input_type=_CSTEAMTV_CREATEBROADCASTCHANNEL_REQUEST,
    output_type=_CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE,
    serialized_options=b'\202\265\030\033Create a channel on SteamTV',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelID',
    full_name='SteamTV.GetBroadcastChannelID',
    index=1,
    containing_service=None,
    input_type=_CSTEAMTV_GETBROADCASTCHANNELID_REQUEST,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE,
    serialized_options=b'\202\265\030AGet a broadcast channel ID for a channel by name or owner SteamID',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetBroadcastChannelProfile',
    full_name='SteamTV.SetBroadcastChannelProfile',
    index=2,
    containing_service=None,
    input_type=_CSTEAMTV_SETBROADCASTCHANNELPROFILE_REQUEST,
    output_type=_CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE,
    serialized_options=b'\202\265\030\"Set broadcast channel profile data',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelProfile',
    full_name='SteamTV.GetBroadcastChannelProfile',
    index=3,
    containing_service=None,
    input_type=_CSTEAMTV_GETBROADCASTCHANNELPROFILE_REQUEST,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE,
    serialized_options=b'\202\265\030\"Get broadcast channel profile data',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetBroadcastChannelImage',
    full_name='SteamTV.SetBroadcastChannelImage',
    index=4,
    containing_service=None,
    input_type=_CSTEAMTV_SETBROADCASTCHANNELIMAGE_REQUEST,
    output_type=_CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE,
    serialized_options=b'\202\265\030 Set broadcast channel image hash',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelImages',
    full_name='SteamTV.GetBroadcastChannelImages',
    index=5,
    containing_service=None,
    input_type=_CSTEAMTV_GETBROADCASTCHANNELIMAGES_REQUEST,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE,
    serialized_options=b'\202\265\030\034Get broadcast channel images',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetBroadcastChannelLinkRegions',
    full_name='SteamTV.SetBroadcastChannelLinkRegions',
    index=6,
    containing_service=None,
    input_type=_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST,
    output_type=_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE,
    serialized_options=b'\202\265\030\"Set broadcast channel link regions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelLinks',
    full_name='SteamTV.GetBroadcastChannelLinks',
    index=7,
    containing_service=None,
    input_type=_CSTEAMTV_GETBROADCASTCHANNELLINKS_REQUEST,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE,
    serialized_options=b'\202\265\030\"Get broadcast channel link regions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelBroadcasters',
    full_name='SteamTV.GetBroadcastChannelBroadcasters',
    index=8,
    containing_service=None,
    input_type=_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_REQUEST,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE,
    serialized_options=b'\202\265\030-Get list of broadcaster info for this channel',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFollowedChannels',
    full_name='SteamTV.GetFollowedChannels',
    index=9,
    containing_service=None,
    input_type=_CSTEAMTV_GETFOLLOWEDCHANNELS_REQUEST,
    output_type=_CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE,
    serialized_options=b'\202\265\030)Get list of followed channels by a viewer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSubscribedChannels',
    full_name='SteamTV.GetSubscribedChannels',
    index=10,
    containing_service=None,
    input_type=_CSTEAMTV_GETSUBSCRIBEDCHANNELS_REQUEST,
    output_type=_CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE,
    serialized_options=b'\202\265\030,Get list of channels a user is subscribed to',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelStatus',
    full_name='SteamTV.GetBroadcastChannelStatus',
    index=11,
    containing_service=None,
    input_type=_CSTEAMTV_GETBROADCASTCHANNELSTATUS_REQUEST,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE,
    serialized_options=b'\202\265\030!Get broadcast channel live status',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FollowBroadcastChannel',
    full_name='SteamTV.FollowBroadcastChannel',
    index=12,
    containing_service=None,
    input_type=_CSTEAMTV_FOLLOWBROADCASTCHANNEL_REQUEST,
    output_type=_CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE,
    serialized_options=b'\202\265\030\032Follow a broadcast channel',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeBroadcastChannel',
    full_name='SteamTV.SubscribeBroadcastChannel',
    index=13,
    containing_service=None,
    input_type=_CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_REQUEST,
    output_type=_CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE,
    serialized_options=b'\202\265\030 Subscribe to a broadcast channel',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelClips',
    full_name='SteamTV.GetBroadcastChannelClips',
    index=14,
    containing_service=None,
    input_type=_CSTEAMTV_GETBROADCASTCHANNELCLIPS_REQUEST,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE,
    serialized_options=b'\202\265\030\033Get broadcast channel clips',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReportBroadcastChannel',
    full_name='SteamTV.ReportBroadcastChannel',
    index=15,
    containing_service=None,
    input_type=_CSTEAMTV_REPORTBROADCASTCHANNEL_REQUEST,
    output_type=_CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE,
    serialized_options=b'\202\265\030\032Report a broadcast channel',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelInteraction',
    full_name='SteamTV.GetBroadcastChannelInteraction',
    index=16,
    containing_service=None,
    input_type=_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_REQUEST,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE,
    serialized_options=b'\202\265\0306Get user\'s interaction status with a broadcast channel',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGames',
    full_name='SteamTV.GetGames',
    index=17,
    containing_service=None,
    input_type=_CSTEAMTV_GETGAMES_REQUEST,
    output_type=_CSTEAMTV_GETGAMES_RESPONSE,
    serialized_options=b'\202\265\030*Get list of games with active broadcasters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChannels',
    full_name='SteamTV.GetChannels',
    index=18,
    containing_service=None,
    input_type=_CSTEAMTV_GETCHANNELS_REQUEST,
    output_type=_CSTEAMTV_GETCHANNELS_RESPONSE,
    serialized_options=b'\202\265\030+Get the list of featured broadcast channels',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddChatBan',
    full_name='SteamTV.AddChatBan',
    index=19,
    containing_service=None,
    input_type=_CSTEAMTV_ADDCHATBAN_REQUEST,
    output_type=_CSTEAMTV_ADDCHATBAN_RESPONSE,
    serialized_options=b'\202\265\030QSet the ban for a specific broadcaster. The issuer is the logged in steam account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChatBans',
    full_name='SteamTV.GetChatBans',
    index=20,
    containing_service=None,
    input_type=_CSTEAMTV_GETCHATBANS_REQUEST,
    output_type=_CSTEAMTV_GETCHATBANS_RESPONSE,
    serialized_options=b'\202\265\030-Get list of bans for a specific broadcaster. ',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddChatModerator',
    full_name='SteamTV.AddChatModerator',
    index=21,
    containing_service=None,
    input_type=_CSTEAMTV_ADDCHATMODERATOR_REQUEST,
    output_type=_CSTEAMTV_ADDCHATMODERATOR_RESPONSE,
    serialized_options=b'\202\265\0304Add or remove a moderator for this broadcast channel',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChatModerators',
    full_name='SteamTV.GetChatModerators',
    index=22,
    containing_service=None,
    input_type=_CSTEAMTV_GETCHATMODERATORS_REQUEST,
    output_type=_CSTEAMTV_GETCHATMODERATORS_RESPONSE,
    serialized_options=b'\202\265\0309Returns the list of moderators for this broadcast channel',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddWordBan',
    full_name='SteamTV.AddWordBan',
    index=23,
    containing_service=None,
    input_type=_CSTEAMTV_ADDWORDBAN_REQUEST,
    output_type=_CSTEAMTV_ADDWORDBAN_RESPONSE,
    serialized_options=b'\202\265\030=Add or remove a banned keyword in this broadcast channel chat',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWordBans',
    full_name='SteamTV.GetWordBans',
    index=24,
    containing_service=None,
    input_type=_CSTEAMTV_GETWORDBANS_REQUEST,
    output_type=_CSTEAMTV_GETWORDBANS_RESPONSE,
    serialized_options=b'\202\265\030>Returns the list of banned keywords for this broadcast channel',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinChat',
    full_name='SteamTV.JoinChat',
    index=25,
    containing_service=None,
    input_type=_CSTEAMTV_JOINCHAT_REQUEST,
    output_type=_CSTEAMTV_JOINCHAT_RESPONSE,
    serialized_options=b'\202\265\030&Joins the chat channel for a broadcast',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='SteamTV.Search',
    index=26,
    containing_service=None,
    input_type=_CSTEAMTV_SEARCH_REQUEST,
    output_type=_CSTEAMTV_SEARCH_RESPONSE,
    serialized_options=b'\202\265\0307Searches for broadcast channels based on input keywords',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSteamTVUserSettings',
    full_name='SteamTV.GetSteamTVUserSettings',
    index=27,
    containing_service=None,
    input_type=_CSTEAMTV_GETSTEAMTVUSERSETTINGS_REQUEST,
    output_type=_CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030!Returns a user\'s SteamTV settings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSteamTVUserSettings',
    full_name='SteamTV.SetSteamTVUserSettings',
    index=28,
    containing_service=None,
    input_type=_CSTEAMTV_SETSTEAMTVUSERSETTINGS_REQUEST,
    output_type=_CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030\036Sets a user\'s SteamTV settings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMyBroadcastChannels',
    full_name='SteamTV.GetMyBroadcastChannels',
    index=29,
    containing_service=None,
    input_type=_CSTEAMTV_GETMYBROADCASTCHANNELS_REQUEST,
    output_type=_CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE,
    serialized_options=b'\202\265\0306Gets the broadcast channels that the current user owns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHomePageContents',
    full_name='SteamTV.GetHomePageContents',
    index=30,
    containing_service=None,
    input_type=_CSTEAMTV_GETHOMEPAGECONTENTS_REQUEST,
    output_type=_CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE,
    serialized_options=b'\202\265\030\"Returns homepage contents for user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AppCheer',
    full_name='SteamTV.AppCheer',
    index=31,
    containing_service=None,
    input_type=_CSTEAMTV_APPCHEER_REQUEST,
    output_type=_CSTEAMTV_APPCHEER_RESPONSE,
    serialized_options=b'\202\265\030AThe user is cheering for a specific broadcast for a specific app.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STEAMTV)

DESCRIPTOR.services_by_name['SteamTV'] = _STEAMTV

SteamTV = service_reflection.GeneratedServiceType('SteamTV', (_service.Service,), dict(
  DESCRIPTOR = _STEAMTV,
  __module__ = 'steammessages_steamtv_pb2'
  ))

SteamTV_Stub = service_reflection.GeneratedServiceStubType('SteamTV_Stub', (SteamTV,), dict(
  DESCRIPTOR = _STEAMTV,
  __module__ = 'steammessages_steamtv_pb2'
  ))


# @@protoc_insertion_point(module_scope)
